/*  
 * cooktop.js
 * 
 * Copyright ( c ) 2016 by Samsung Electronics, Inc.,
 *
 * This software is the confidential and proprietary information
 * of Samsung Electronics, Inc. ("Confidential Information").  You
 * shall not disclose such Confidential Information and shall use
 * it only in accordance with the terms of the license agreement
 * you entered into with Samsung.
 *
 * Created on : Thu Dec 08 15:35:26 KST 2016
 * Owner      : SRI
 * Author     : namit.bansal@samsung.com
 */

var app = angular.module("SmartThings", ['toaster', 'ngSanitize', 'ui.router', 'ngTouch']);

app.config(['$stateProvider', function ($stateProvider) {
        var MainLoadingPage = {
            name: 'MainLoadingPage',
            url: '/',
            templateUrl: 'common/views/splash.html'
        },
        BurnerHomePage = {
            name: 'BurnerHomePage',
            url: '/',
            templateUrl: 'COOKTOP/views/BurnerHomeScreen.html'
        },
        BurnerTimerPage = {
            name: 'BurnerTimerPage',
            url: '/',
            templateUrl: 'BurnerTimerScreen.html'
        },
        KitchenTimerPage = {
            name: 'KitchenTimerPage',
            url: '/',
            templateUrl: 'KitchenTimerScreen.html'
        },
        HoodTimerPage = {
            name: 'HoodTimerPage',
            url: '/',
            templateUrl: 'HoodTimerScreen.html'
        },
        RecipeListPage = {
            name: 'RecipeListPage',
            url: '/',
            templateUrl: 'COOKTOP/views/RecipeListScreen.html'
        },
        RecipeIngredientPage = {
            name: 'RecipeIngredientPage',
            url: '/',
            templateUrl: 'COOKTOP/views/RecipeIngredientScreen.html'
        },
        SettingPage = {
            name: 'SettingPage',
            url: '/',
            templateUrl: 'COOKTOP/views/SettingScreen.html'
        },
        AboutPage = {
            name: 'AboutPage',
            url: '/',
            templateUrl: 'COOKTOP/views/AboutScreen.html'
        },
        SmartCarePage = {
            name: 'SmartCarePage',
            url: '/',
            templateUrl: 'COOKTOP/views/SmartCareScreen.html'
        },
        SmartCareNoErrorPage = {
            name: 'SmartCareNoErrorPage',
            url: '/',
            templateUrl: 'COOKTOP/views/SmartCareNoErrorScreen.html'
        },
        ErrorPage = {
            name: 'ErrorPage',
            url: '/',
            templateUrl: 'COOKTOP/views/ErrorScreen.html'
        };

        $stateProvider.state(MainLoadingPage);
        $stateProvider.state(BurnerHomePage);
        $stateProvider.state(KitchenTimerPage);
        $stateProvider.state(BurnerTimerPage);
        $stateProvider.state(RecipeListPage);
        $stateProvider.state(RecipeIngredientPage);
        $stateProvider.state(HoodTimerPage);
        $stateProvider.state(SettingPage);
        $stateProvider.state(AboutPage);
        $stateProvider.state(SmartCarePage);
        $stateProvider.state(SmartCareNoErrorPage);
        $stateProvider.state(ErrorPage);

    }]);

app.run(['$state', function ($state) {
        $state.transitionTo('MainLoadingPage');
    }]);

app.controller("cooktopAppController", ['$scope', '$state', 'SHPService', 'toaster', '$timeout', '$interval', cooktopAppController]);

function cooktopAppController($scope, $state, SHPService, toaster, $timeout, $interval) {
    var langArr = Object.keys(LANGUAGE_FILE.language), Debug_tag = 'CT : ', justFirstTime = true, configTimer = null, Sec20Call = 20000, promiseAbout, timerMaxValue = 99,
            bridgeSelected = 'off', errorRemoved = true, changeSmartCarePage = false, doNotChangeScreen = false, scroll_middle_area = document.getElementById("scrollable_area_others"), parseNotificationFlag = false,
            kitchenTimerDrag = $("#kitchenTimerDrag"), burnerTimerDrag = $("#burnerTimerDrag"), hoodTimerDrag = $("#hoodTimerDrag"), roundShape;

    var COOKTOP_SCREENS = {
        COOKTOP_MAIN_LOADING_PAGE: 1,
        COOKTOP_BURNER_HOME_PAGE: 2,
        COOKTOP_KITCHEN_TIMER_PAGE: 3,
        COOKTOP_HOOD_TIMER_PAGE: 4,
        COOKTOP_SETTING_PAGE: 5,
        COOKTOP_ABOUT_PAGE: 6,
        COOKTOP_ERROR_PAGE: 7,
        COOKTOP_SMART_CARE_PAGE: 8,
        COOKTOP_SMART_CARE_NO_ERROR_PAGE: 9,
        COOKTOP_RECIPE_LIST_PAGE: 10,
        COOKTOP_RECIPE_INGREDIENT_PAGE: 11,
        COOKTOP_BURNER_TIMER_PAGE: 12
    },
    COOKTOP_COMMANDS = {
        "hoodTimer": "hoodTimer",
        "hoodPower": "hoodPower",
        "hoodLight": "hoodLight",
        "hoodFan": "hoodFan",
        "getDevices": "getDevices",
        "runOnNative": "runOnNative",
        "kitchenTimer": "kitchenTimer",
        "BurnerTimer": "BurnerTimer",
        "showModuleVersion": "showModuleVersion",
        "smartCareDiagnosis": "smartCareDiagnosis"
    },
    COOKTOP_ALERT_STATE = {
        ALERT_NONE: 0,
        ALERT_START_COOKING: 1,
        ALERT_CANCEL_COOKING: 2,
        ALERT_CONNECTION_ERROR: 3,
        ALERT_DEVELOPER_INFO: 4,
        ALERT_TIMER_FINISH: 5,
        ALERT_CHILD_LOCK: 6,
        ALERT_HOOD_TIMER_FINISH: 7,
        ALERT_SERVICE_CALL: 8,
        ALERT_BURNER_TIMER: 9
    };

    if (LANG.toUpperCase() === 'ES-XL') {
        LANG = 'ES-MX';
    }
    if (langArr.indexOf(LANG.toUpperCase()) !== -1) {
        $scope.translation = LANGUAGE_FILE["language"][LANG.toUpperCase()];
    } else if (langArr.indexOf(LANG.toUpperCase().substring(0, 2)) !== -1) {
        $scope.translation = LANGUAGE_FILE["language"][LANG.toUpperCase().substring(0, 2)];
    } else {
        $scope.translation = LANGUAGE_FILE["language"]["DEFAULT"];
    }
    
    $scope.selectedLanguage = LANG.toUpperCase().substring(0, 2);
    $scope.isSpanishLanguage = LANG.toUpperCase().substring(0, 2) === "ES";
    $scope.isFrenchLanguage = LANG.toUpperCase().substring(0, 2) === "FR";
    
    $scope.switchON = 'I';
    $scope.switchOff = 'O';
    if (LANG.toUpperCase().indexOf('EN') !== -1) {
        $scope.switchON = 'ON';
        $scope.switchOff = 'OFF';
    }

    loadVariables();

    function isTextInput(node) {
        return ['INPUT', 'TEXTAREA'].indexOf(node.nodeName) !== -1;
    }

    document.addEventListener('touchend', function (e) {
        if (!isTextInput(e.target) && isTextInput(document.activeElement)) {
            document.activeElement.blur();
        }
    }, false);

    function loadVariables() {
        $scope.isStatic = false;
        $scope.isAppV2 = false;
        $scope.hoodOff = false;
        $scope.showHood = false;
        $scope.hoodLight = false;
        $scope.loadingBar = false;
        $scope.showSmartCare = false;
        $scope.isTempFocusOn = false;
        $scope.supportHrTimer = false;
        $scope.ch0FlexUpperOn = false;
        $scope.ch0FlexLowerOn = false;
        $scope.ch1FlexUpperOn = false;
        $scope.ch1FlexLowerOn = false;
        $scope.cTopTabSelected = true;
        $scope.appAtForeground = false;
        $scope.showKitchenTimer = false;
        $scope.autoConnectivity = false;
        $scope.headerBarVisible = false;
        $scope.TabsVisibleAtPage = false;
        $scope.mainLoadingScreen = false;
        $scope.moreOptionVisible = false;
        $scope.showBurnerInfoPopup = false;
        $scope.showFullScreenPopup = false;
        $scope.showMenuOptionPopup = false;
        $scope.cookTopBurnerPause = false;
        $scope.remoteControlEnabled = false;

        $scope.checkResponse = [];
        $scope.runningBurner = [];

        $scope.kitchenTimer = 0;
        $scope.hoodTimer = 0;
        $scope.selectedFanValue = 1;
        $scope.flexCoilSelectedValue = -1;

        $scope.cookTopType = '1';
        $scope.rTopType = '48';
        $scope.fanStatus = 'low';
        $scope.smartControl = 'OFF';
        $scope.fanText = "WEBMOB_device_hood_low";
        $scope.startStopState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
        $scope.selectedBurnerDetail = '';
        $scope.KitchenTimerState = 'Ready';
        $scope.hoodLightPosition = 'off';
        $scope.timerText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1;
        $scope.timerStopText = $scope.translation.WEBMOB_device_hood_set_time_reset_for_stop;
        $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
        $scope.cookTopBurnerBridge = 'COOKTOP/assets/img/burner/ct_ect_burner_sync_off';
        $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_MAIN_LOADING_PAGE;
        $scope.FugBurnerDetail = $scope.translation.WEBMOB_device_cooktop_status1.replace(/#1#/, 3);

        $scope.init = init;
        $scope.closeApp = closeApp;
        $scope.onBackPressed = onBackPressed;
        $scope.callGetDevice = callGetDevice;
        $scope.parseStaticData = parseStaticData;
        $scope.parseDeviceData = parseDeviceData;
        $scope.handleStatusCode = handleStatusCode;
        $scope.updateDeviceData = updateDeviceData;
        $scope.parseNotification = parseNotification;
        $scope.onBackPressedEvent = onBackPressedEvent;
        $scope.parseConfiguration = parseConfiguration;
        $scope.requestFailHandler = requestFailHandler;
        $scope.parseRequestAccepted = parseRequestAccepted;
        $scope.parseRequestResponse = parseRequestResponse;
        $scope.parseModuleInformation = parseModuleInformation;
        $scope.showConnectionFailurePopup = showConnectionFailurePopup;
        $scope.closeConnectionFailurePopup = closeConnectionFailurePopup;

        $scope.noScroll = noScroll;
        $scope.goToAbout = goToAbout;
        $scope.selectRecipe = selectRecipe;
        $scope.detailRecipe = detailRecipe;
        $scope.cTopTabClick = cTopTabClick;
        $scope.goToSettings = goToSettings;
        $scope.selectBurner = selectBurner;
        $scope.inputKeyDown = inputKeyDown;
        $scope.addHoodTimer = addHoodTimer;
        $scope.onAboutAction = onAboutAction;
        $scope.hoodFanButton = hoodFanButton;
        $scope.gotoHoodTimer = gotoHoodTimer;
        $scope.showFanOption = showFanOption;
        $scope.hideFanOption = hideFanOption;
        $scope.addBurnerTimer = addBurnerTimer;
        $scope.hideDummyInbox = hideDummyInbox;
        $scope.showDummyInbox = showDummyInbox;
        $scope.hideMenuOption = hideMenuOption;
        $scope.showMenuOption = showMenuOption;
        $scope.resetHoodTimer = resetHoodTimer;
        $scope.startHoodTimer = startHoodTimer;
        $scope.gotoRecipePage = gotoRecipePage;
        $scope.setBurnerTimer = setBurnerTimer;
        $scope.goToBurnerTimer = goToBurnerTimer;
        $scope.hoodLightButton = hoodLightButton;
        $scope.addKitchenTimer = addKitchenTimer;
        $scope.versionTouchEnd = versionTouchEnd;
        $scope.hoodPowerButton = hoodPowerButton;
        $scope.swipeCookingLeft = swipeCookingLeft;
        $scope.startBurnerTimer = startBurnerTimer;
        $scope.resetBurnerTimer = resetBurnerTimer;
        $scope.gotoSmartControl = gotoSmartControl;
        $scope.gotoKitchenTimer = gotoKitchenTimer;
        $scope.updateTimerValue = updateTimerValue;
        $scope.swipeCookingRight = swipeCookingRight;
        $scope.showUsageHelpPage = showUsageHelpPage;
        $scope.resetKitchenTimer = resetKitchenTimer;
        $scope.startKitchenTimer = startKitchenTimer;
        $scope.versionTouchStart = versionTouchStart;
        $scope.onFlexCoilClicked = onFlexCoilClicked;
        $scope.hideRTopInfoPopup = hideRTopInfoPopup;
        $scope.showRTopInfoPopups = showRTopInfoPopups;
        $scope.closeUsageHelpPage = closeUsageHelpPage;
        $scope.hideBurnerInfoPopup = hideBurnerInfoPopup;
        $scope.onAlertButton1Click = onAlertButton1Click;
        $scope.onAlertButton2Click = onAlertButton2Click;
        $scope.smartcareerrorcheck = smartcareerrorcheck;
        $scope.showPowerLevelDetail = showPowerLevelDetail;
        $scope.showBurnerTimeDetail = showBurnerTimeDetail;
        $scope.doOnServiceCallPopup = doOnServiceCallPopup;
        $scope.updateHoodTimerValue = updateHoodTimerValue;
        $scope.doValidationForTimer = doValidationForTimer;
        $scope.updateBurnerTimerValue = updateBurnerTimerValue;
        $scope.hideSmartControlOption = hideSmartControlOption;
        $scope.toggleAutoConnectivity = toggleAutoConnectivity;
        $scope.doValidationForHoodTimer = doValidationForHoodTimer;
        $scope.doValidationForBurnerTimer = doValidationForBurnerTimer;

        $scope.CooktopRecipes = [{
                id: 1,
                title: 'WEBMOB_device_us_cooktop_recipe_frenchtoast_with_bacon_and_maplesyrup_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_frenchtoast_with_bacon_and_maplesyrup_ingredient',
                time: '10-15 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_frenchtoast_with_bacon_and_maplesyrup_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_frenchtoast_with_bacon_and_maplesyrup_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_frenchtoast_with_bacon_and_maplesyrup_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_01_french_toasts_with_bacon_and_maple_syrup.png'
            }, {
                id: 2,
                title: 'WEBMOB_device_us_cooktop_recipe_manhattan_clam_chowder_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_manhattan_clam_chowder_ingredient',
                time: '40-50 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_manhattan_clam_chowder_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_manhattan_clam_chowder_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_manhattan_clam_chowder_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_02_manhattan_clam_chowder.png'
            }, {
                id: 3,
                title: 'WEBMOB_device_us_cooktop_recipe_rainbow_pasta_salad_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_rainbow_pasta_salad_ingredient',
                time: '20-30 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_rainbow_pasta_salad_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_rainbow_pasta_salad_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_rainbow_pasta_salad_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_03_rainbow_pasta_salad.png'
            }, {
                id: 4,
                title: 'WEBMOB_device_us_cooktop_recipe_lemon_grilled_chicken_breasts_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_lemon_grilled_chicken_breasts_ingredient',
                time: '15-20 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_lemon_grilled_chicken_breasts_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_lemon_grilled_chicken_breasts_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_lemon_grilled_chicken_breasts_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_04_lemon_grilled_chicken_breasts.png'
            }, {
                id: 5,
                title: 'WEBMOB_device_us_cooktop_recipe_grilled_salmon_steaks_with_asparagus_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_grilled_salmon_steaks_with_asparagus_ingredient',
                time: '10-15 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_grilled_salmon_steaks_with_asparagus_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_grilled_salmon_steaks_with_asparagus_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_05_grilled_salmon_steaks_with_asparagus.png'
            }, {
                id: 6,
                title: 'WEBMOB_device_us_cooktop_recipe_grilled_lime_shrimp_skewers_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_grilled_lime_shrimp_skewers_ingredient',
                time: '10-15 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_grilled_lime_shrimp_skewers_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_grilled_lime_shrimp_skewers_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_06_grilled_lime_shrimp_skewers.png'
            }, {
                id: 7,
                title: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_ingredient',
                time: '30-40 ' + $scope.translation.WEBMOB_common_min,
                steps: 4,
                serving: 4,
                level: '★★★☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_step3_',
                step4: 'WEBMOB_device_us_cooktop_recipe_hamburger_steaks_with_onion_gravy_step4_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_07_hamburger_steaks_with_onion_gravy.png'
            }, {
                id: 8,
                title: 'WEBMOB_device_us_cooktop_recipe_chicken_cutlets_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_chicken_cutlets_ingredient',
                time: '30-40 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★★☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_chicken_cutlets_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_chicken_cutlets_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_08_chicken_cutlets.png'
            }, {
                id: 9,
                title: 'WEBMOB_device_us_cooktop_recipe_beef_stew_with_potato_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_beef_stew_with_potato_ingredient',
                time: '100-120 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★★☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_beef_stew_with_potato_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_beef_stew_with_potato_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_beef_stew_with_potato_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_09_beef_stew_with_potato.png'
            }, {
                id: 10,
                title: 'WEBMOB_device_us_cooktop_recipe_beef_steak_fajitas_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_beef_steak_fajitas_ingredient',
                time: '20-30 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★★☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_beef_steak_fajitas_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_beef_steak_fajitas_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_10_beef_steak_fajitas.png'
            }, {
                id: 11,
                title: 'WEBMOB_device_us_cooktop_recipe_shrimp_with_tomatoes_and_olives_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_shrimp_with_tomatoes_and_olives_ingredient',
                time: '10-20 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_shrimp_with_tomatoes_and_olives_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_shrimp_with_tomatoes_and_olives_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_shrimp_with_tomatoes_and_olives_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_11_shrimp_with_tomatoes_and_olives.png'
            }, {
                id: 12,
                title: 'WEBMOB_device_us_cooktop_recipe_spanish_potato_omelet_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_spanish_potato_omelet_ingredient',
                time: '30-40 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: '4~6',
                level: '★★★☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_spanish_potato_omelet_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_spanish_potato_omelet_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_spanish_potato_omelet_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_12_spanish_potato_omelet.png'
            }, {
                id: 13,
                title: 'WEBMOB_device_us_cooktop_recipe_shrimp_fettuccine_alfredo_pan_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_shrimp_fettuccine_alfredo_pan_ingredient',
                time: '30-40 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_shrimp_fettuccine_alfredo_pan_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_shrimp_fettuccine_alfredo_pan_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_13_shrimp_fettuccine_alfredo.png'
            }, {
                id: 14,
                title: 'WEBMOB_device_us_cooktop_recipe_grilled_vegetables_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_grilled_vegetables_ingredient',
                time: '10-20 ' + $scope.translation.WEBMOB_common_min,
                steps: 3,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_grilled_vegetables_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_grilled_vegetables_step2_',
                step3: 'WEBMOB_device_us_cooktop_recipe_grilled_vegetables_step3_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_14_grilled_vegetables.png'
            }, {
                id: 15,
                title: 'WEBMOB_device_us_cooktop_recipe_tomato_sauce_with_fresh_tomatoes_title',
                ingredient: 'WEBMOB_device_us_cooktop_recipe_tomato_sauce_with_fresh_tomatoes_ingredient',
                time: '40-50 ' + $scope.translation.WEBMOB_common_min,
                steps: 2,
                serving: 4,
                level: '★★☆☆☆',
                step1: 'WEBMOB_device_us_cooktop_recipe_tomato_sauce_with_fresh_tomatoes_step1_',
                step2: 'WEBMOB_device_us_cooktop_recipe_tomato_sauce_with_fresh_tomatoes_step2_',
                image: 'COOKTOP/assets/img/gc_img/gc_img_15_tomato_sauce_with_fresh_tomatoes.png'
            }];

    }

    function debugMessage(msg) {
        if (false) {
            console.log(Debug_tag + ": " + msg + '  >> called from ' + arguments.callee.caller.name);
        }
    }

    function init() {
        debugMessage('init called ' + $scope.appAtForeground + justFirstTime);
        if (!$scope.appAtForeground && justFirstTime) {
            $scope.cookTopInfo = {
                Alarms: [{
                        id: "0",
                        alarmType: "Device",
                        code: "NoPanDetect0",
                        triggeredTime: "2015-11-18T11:03:25"
                    }, {
                        id: "1",
                        alarmType: "Device",
                        code: "NoPanDetect1",
                        triggeredTime: "2015-11-18T11:03:25"
                    }, {
                        id: "2",
                        alarmType: "Device",
                        code: "NoPanDetect2",
                        triggeredTime: "2015-11-18T11:03:25"
                    }, {
                        id: "3",
                        alarmType: "Device",
                        code: "NoPanDetect3",
                        triggeredTime: "2015-11-18T11:03:25"
                    }, {
                        id: "4",
                        alarmType: "Device",
                        code: "NoPanDetect4",
                        triggeredTime: "2015-11-18T11:03:25"
                    }, {
                        id: "5",
                        alarmType: "Device",
                        code: "NoPanDetect5",
                        triggeredTime: "2015-11-18T11:03:25"
                    }],
                ConfigurationLink: {
                    href: "/devices/0/configuration"
                },
                Diagnosis: {
                    diagnosisStart: "Ready"
                },
                InformationLink: {
                    href: "/devices/0/information"
                },
                Mode: {
                    options: [{
                            DeviceType: "NV9500M-/AA0",
                            OperationType: "0",
                            FanSpeed: 0,
                            Lamp: false,
                            MainTimerCurrent: 0,
                            MainTimerSet: 0,
                            MainTimerState: 'Ready',
                            Pause: "0",
                            SyncFlex: 'Off',
                            SyncFlexRight: 'Off',
                            FlexCoilValue: 0,
                            FlexCoilValueRight: 0,
                            PanSize0: "Not_Supported",
                            PanSize1: "Not_Supported",
                            PanSize2: "Not_Supported",
                            PanSize3: "Not_Supported",
                            PanSize4: "Not_Supported",
                            PanSize5: "Not_Supported",
                            OperationState0: "Ready",
                            OperationState1: "Ready",
                            OperationState2: "Ready",
                            OperationState3: "Ready",
                            OperationState4: "Ready",
                            OperationState5: "Ready",
                            OperationState6: "Ready",
                            OperationState7: "Ready",
                            HotSurface0: "0",
                            HotSurface1: "0",
                            HotSurface2: "0",
                            HotSurface3: "0",
                            HotSurface4: "0",
                            HotSurface5: "0",
                            HotSurface0_1: "0",
                            HotSurface1_1: "0",
                            HotSurface2_1: "0",
                            HotSurface3_1: "0",
                            HotSurface4_1: "0",
                            HotSurface5_1: "0",
                            PowerLevel0: "0",
                            PowerLevel1: "0",
                            PowerLevel2: "0",
                            PowerLevel3: "0",
                            PowerLevel4: "0",
                            PowerLevel5: "0",
                            GuidedCooking0: "",
                            GuidedCooking1: "",
                            GuidedCooking2: "",
                            GuidedCooking3: "",
                            GuidedCooking4: "",
                            GuidedCooking5: "",
                            TimerState0: "Ready",
                            TimerState1: "Ready",
                            TimerState2: "Ready",
                            TimerState3: "Ready",
                            TimerState4: "Ready",
                            TimerState5: "Ready",
                            DownCountTimerCurrent0: "0",
                            DownCountTimerCurrent1: "0",
                            DownCountTimerCurrent2: "0",
                            DownCountTimerCurrent3: "0",
                            DownCountTimerCurrent4: "0",
                            DownCountTimerCurrent5: "0",
                            DownCountTimerSet0: "0",
                            DownCountTimerSet1: "0",
                            DownCountTimerSet2: "0",
                            DownCountTimerSet3: "0",
                            DownCountTimerSet4: "0",
                            DownCountTimerSet5: "0"}]
                },
                Operation: {
                    kidsLock: "Ready",
                    power: "On"
                },
                connected: true,
                description: "TP6X_CT_16K",
                id: "0",
                name: "CookTop",
                resources: ["Alarms",
                    "Configuration",
                    "Diagnosis",
                    "Doors",
                    "Information",
                    "Mode",
                    "Operation",
                    "Oven",
                    "Temperatures"],
                type: "CookTop",
                uuid: "F8042EEB-AD39-0000-0000-000000000000"
            };
            $scope.HoodInfo = {Alarms: [{
                        id: "0",
                        alarmType: "",
                        code: "",
                        triggeredTime: ""
                    }],
                ConfigurationLink: {
                    href: "/devices/1/configuration"
                },
                Diagnosis: {
                    diagnosisStart: "Ready"
                },
                InformationLink: {
                    href: "/devices/1/information"
                },
                Mode: {
                    options: [{
                            DeviceType: "NV9300K-/AA4",
                            FanSpeed: 0,
                            Hood: '',
                            Bluetooth: 'On',
                            Lamp: false,
                            BTState: 15,
                            AutoMode: 'On',
                            ShutOffTimerSet: 0,
                            ShutOffTimerCurrent: 0,
                            ShutOffTimerState: 'Ready'}]
                },
                Operation: {
                    power: "Off"
                },
                connected: false,
                description: "TP6X_CT_16K_HOOD",
                id: "1",
                name: "Hood",
                resources: ["Alarms",
                    "Configuration",
                    "Diagnosis",
                    "Doors",
                    "Information",
                    "Mode",
                    "Operation"],
                type: "CookTop",
                uuid: "F8042EEB-AD39-0000-0000-000000000001"
            };
            $scope.cookTopBurnerArray = [{
                    id: 0,
                    AlarmCode: 'NoPanDetect0',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_08',
                    BurnerTime: '',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    BurnerTimeShow: false,
                    PowerLevelShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: '',
                    LowerText: ''
                }, {
                    id: 1,
                    AlarmCode: 'NoPanDetect1',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    BurnerTime: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_08',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    PowerLevelShow: false,
                    BurnerTimeShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: 'ON',
                    LowerText: 'OFF'
                }, {
                    id: 2,
                    AlarmCode: 'NoPanDetect2',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    BurnerTime: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_10',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    PowerLevelShow: false,
                    BurnerTimeShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: '',
                    LowerText: ''
                }, {
                    id: 3,
                    AlarmCode: 'NoPanDetect3',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    BurnerTime: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_10',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    PowerLevelShow: false,
                    BurnerTimeShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: '',
                    LowerText: ''
                }, {
                    id: 4,
                    AlarmCode: 'NoPanDetect4',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    BurnerTime: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_10',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    PowerLevelShow: false,
                    BurnerTimeShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: '',
                    LowerText: ''
                }, {
                    id: 5,
                    AlarmCode: 'NoPanDetect5',
                    PanSize: 'Not_Supported',
                    OperationState: 'Ready',
                    HotSurface: '',
                    HotSurface_1: '',
                    Hotness: false,
                    PowerLevel: '0',
                    PowerLevelValue: '',
                    BurnerTime: '',
                    TimerState: 'Ready',
                    DownCountTimerCurrent: '0',
                    DownCountTimerSet: '0',
                    BurnerImageID: 'burner_circle_10',
                    GuidedCooking: '',
                    GuidedCookingImage: '',
                    subBurnerId: '',
                    SubBurnerSupport: false,
                    ImageOff: true,
                    ImageOn: false,
                    PowerLevelShow: false,
                    BurnerTimeShow: false,
                    ImageSelected: false,
                    CenterText: '',
                    UpperText: '',
                    LowerText: ''
                }, {
                    id: 6,
                    AlarmCode: 'NoPanDetect5',
                    OperationState: 'Ready'
                }, {
                    id: 7,
                    AlarmCode: 'NoPanDetect5',
                    OperationState: 'Ready'
                }];
            $scope.flexCoilStatus = [{
                    Parent: 0, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 0, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 1, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 1, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 4, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 4, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 5, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }, {
                    Parent: 5, FlexOn: false, UpperText: '', CenterText: '', LowerText: ''
                }];
            $scope.fanMenuList = [{
                    id: 1,
                    title: 'WEBMOB_device_hood_low'
                }, {
                    id: 2,
                    title: 'WEBMOB_device_hood_medium'
                }, {
                    id: 3,
                    title: 'WEBMOB_device_hood_high'
                }, {
                    id: 4,
                    title: 'WEBMOB_device_hood_boost'
                }/*, {
                 id: 5,
                 title: 'WEBMOB_device_hood_auto'
                 }*/];
        }
    }

    function updateDeviceData(data) {
        //debugMessage("updateDeviceData " + data);
        SHPService.updateDeviceData($scope, data);
    }

    function callGetDevice() {
        debugMessage("callGetDevice ");
        SHPService.getDevices($scope);
    }

    function configurationCall() {
        if (!$scope.isStatic) {
            debugMessage("configurationCall");
            if (!!!configTimer) {
                configTimer = $interval(function () {
                    debugMessage("configurationCall Interval call");
                    //nativeInterface.getResourceUrl("/" + $scope.peerId + "/devices/0/configuration");
                    $scope.appAtForeground = true;
                    SHPService.sendSHPCommand("GET", "/" + $scope.peerId + "/devices", "", false);
                }, Sec20Call);
            }
        }
    }

    function parseStaticData() {
        debugMessage("parseStaticData");
        init();
        initializeScreen();
        $scope.hoodTimer = 10;
        $scope.showSmartCare = true;
        $scope.KitchenTimerState = 'Run';
        $scope.HoodInfo.Operation.power = 'On';
        $scope.HoodInfo.Mode.options[0].Bluetooth = 'On';
        $scope.HoodInfo.Mode.options[0].Hood = 'disconnected';
        $scope.cookTopInfo.Mode.options[0].FlexCoilValue = 5;
        $scope.cookTopInfo.Mode.options[0].MainTimerCurrent = 85;
        $scope.cookTopInfo.Mode.options[0].FlexCoilValueRight = 10;
        parseFlexCoilOnOffInfo();
        parseFlexCoilOnOffInfoRight();
        $scope.cookTopBurnerArray[1].OperationState = 'Run';
        $scope.cookTopBurnerArray[1].DownCountTimerCurrent = '3500';
        $scope.cookTopBurnerArray[1].TimerState = 'Run';
        $scope.cookTopBurnerArray[3].OperationState = 'Run';
        $scope.cookTopBurnerArray[3].GuidedCooking = 5;
        $scope.cookTopBurnerArray[3].DownCountTimerCurrent = '3600';
        $scope.cookTopBurnerArray[4].OperationState = 'Run';
        $scope.cookTopBurnerArray[4].PowerLevel = '5.5';
        $scope.cookTopBurnerArray[4].GuidedCooking = 11;
        $scope.cookTopBurnerArray[4].DownCountTimerCurrent = '4500';
        $scope.cookTopBurnerArray[4].TimerState = 'Run';
        $scope.cookTopBurnerArray[5].OperationState = 'Run';
        $scope.cookTopBurnerArray[5].PowerLevel = '9.0';
        $scope.cookTopBurnerArray[3].GuidedCookingImage = parseGuidedCookingImage(5);
        $scope.cookTopBurnerArray[4].GuidedCookingImage = parseGuidedCookingImage(11);
        showCurrentScreen();
    }

    function parseRequestAccepted(response) {
        debugMessage("parseNotificationData configInfo : " + JSON.stringify(response));
    }

    function parseRequestResponse(response) {
        debugMessage("parseRequestResponse");
        if (angular.isDefined(response["status"]) && response["status"] === 99000) {
            showConnectionFailurePopup();
        }
        if (angular.isDefined(response["status"]) && (response["status"] >= 200 || response.status < 300)) {
            $scope.handleStatusCode(response.status, response);
        }
        if (angular.isDefined(response["data"]["Configuration"])) {
            parseConfiguration(response["data"]["Configuration"], response.resourceURL);
        }
        if (angular.isDefined(response["data"]["Information"])) {
            parseModuleInformation(response["data"]["Information"]);
        }
        if (angular.isDefined(response["data"][0]) && angular.isDefined(response["data"][0]["Device"]) && angular.isDefined(response["data"][0]["Device"]["scsConnectionState"])) {
            if (!response["data"][0]["Device"]["scsConnectionState"]) {
                showConnectionFailurePopup();
            } else if (response["data"][0]["Device"]["scsConnectionState"]) {
                $scope.closeConnectionFailurePopup();
                $scope.autoCall = true;
                $scope.appAtForeground = true;
                callGetDevice();
            }
            return;
        }

        if (angular.isDefined(response["data"]["Devices"])) {
            init();
            parseDeviceData(response.data.Devices);
            if (!!!$scope.loadingBar) { // No loading bar means request handled properly. So, clear array.
                SHPService.clearStopVarArray();
            }
        }
    }

    function parseDeviceData(devices) {
        debugMessage("deviceUuid from app.js is :" + $scope.deviceUuid);
        if (angular.isDefined(devices) && angular.isDefined(devices[0]) && angular.isDefined(devices[0]["uuid"])) {
            if ($scope.deviceUuid !== devices[0]["uuid"] && $scope.deviceUuid !== devices[1]["uuid"]) {
                debugMessage("return due to missMatch UUID");
                return;
            }
        }

        debugMessage(JSON.stringify(devices));

        if (devices instanceof Array) { //Added a check to avoid error in case "devices" is not array 
            devices.forEach(function (value) {
                if (value["id"] === '0') {
                    parseCooktopNotification(value);
                }
                if (value["id"] === '1' || value["id"] === '16') {
                    parseHoodNotification(value);
                }
            });
        } else if (angular.isDefined(devices['Operation']) && devices['Operation'] === '') {
            // sometimes set is sending  devices as {"Operation":""}, added the condition just to avoid any issue that it can cause
            return;
        } else {
            //do nothing
        }
        $scope.appAtForeground = false;
        if (justFirstTime) {
            if (!$scope.isStatic) {
                nativeInterface.getResourceUrl("/" + $scope.peerId + "/devices/0/configuration");
            }
            configurationCall();
            return;
        }
        if (!justFirstTime) {
            dismissLoadingBar(COOKTOP_COMMANDS.getDevices);
            initializeScreen();
            showCurrentScreen();
        }
    }

    function parseConfiguration(configInfo) {
        debugMessage("parseNotificationData configInfo : " + JSON.stringify(configInfo));
        $scope.parseConfig = true;
        parseNotificationFlag = true;
        if (angular.isDefined(configInfo["remoteControlEnabled"])) {
            $scope.remoteControlEnabled = configInfo["remoteControlEnabled"];
        }
        $scope.smartControl = $scope.remoteControlEnabled ? 'ON' : 'OFF';
        if (angular.isDefined(configInfo["region"])) {
            $scope.region = configInfo["region"];
        }
        if (justFirstTime) {
            dismissLoadingBar(COOKTOP_COMMANDS.getDevices);
            initializeScreen();
            showCurrentScreen();
        }
    }

    function parseNotification(response) {
        debugMessage("parseNotification ");
        if (angular.isDefined(response["softKeypadVisibility"])) {
            hideInputBoxFocus();
        }
        if (!angular.isDefined(response["data"])) {
            return;
        }
        if (response["data"] === "backPressed") {
            //if loding bar visible, don't handle back key
            if (!!!$scope.loadingBar) {
                onBackPressed();
            }
            return;
        }
        if (angular.isDefined(response["data"]["mobileTimeChanged"])) {
            return;
        }
        if (angular.isDefined(response["data"][0]) && angular.isDefined(response["data"][0]["Device"]) && angular.isDefined(response["data"][0]["Device"]["scsConnectionState"])) {
            if (!response["data"][0]["Device"]["scsConnectionState"]) {
                showConnectionFailurePopup();
            } else if (response["data"][0]["Device"]["scsConnectionState"]) {
                $scope.closeConnectionFailurePopup();
                $scope.autoCall = true;
                $scope.appAtForeground = true;
                callGetDevice();
            }
            return;
        }
        if (angular.isDefined(response["data"]["isApplicationActive"]) && !$scope.isStatic) {
            $scope.autoCall = true;
            $scope.appAtForeground = true;
            callGetDevice();
            return;
        } else {
            $scope.parseNotiLength = response["data"].length;
            response["data"].forEach(function (value) {
                $scope.parseNotiLength--;
                parseNotificationData(value);
            });
        }
    }


    function parseNotificationData(notification) {
        debugMessage("parseNotificationData : " + JSON.stringify(notification));
        if ($scope.checkResponse.indexOf(COOKTOP_COMMANDS.getDevices) !== -1) {
            debugMessage("ignore notification if getDevice requested ");
            return;
        }
        if (angular.isDefined(notification["uuid"])) {
            if ($scope.cookTopInfo !== undefined && notification["uuid"] === $scope.cookTopInfo.uuid) {
                parseCooktopNotification(notification);
                if ($scope.parseNotiLength === 0) {
                    $scope.appAtForeground = false;
                    showCurrentScreen();
                }
            } else if ($scope.HoodInfo !== undefined && notification["uuid"] === $scope.HoodInfo.uuid) {
                parseHoodNotification(notification);
                if ($scope.parseNotiLength === 0) {
                    $scope.appAtForeground = false;
                    showCurrentScreen();
                }
            } else {
                debugMessage("parseNotificationData uuid not matched notification uuid " + notification["uuid"]);
                $scope.appAtForeground = true;
                SHPService.sendSHPCommand("GET", "/" + $scope.peerId + "/devices", "", false);
            }
        }
    }

    function parseModuleInformation(moduleInfo) {
        debugMessage("parseModuleInformation " + JSON.stringify(moduleInfo));
        if (angular.isDefined(moduleInfo.Versions) && moduleInfo.Versions.length > 0) {
            $scope.moduleInfoText = "Software Ver : " + moduleInfo.Versions[0].number + " <br> Firmware Ver : " + moduleInfo.Versions[1].number;
            dismissLoadingBar(COOKTOP_COMMANDS.showModuleVersion);
            debugMessage("Infotext : " + $scope.moduleInfoText);
            showcustDialog(COOKTOP_ALERT_STATE.ALERT_DEVELOPER_INFO, $scope.translation.WEBMOB_common_version_info, $scope.moduleInfoText, $scope.translation.WEBMOB_common_ok, '');
        }
    }

    function parseCooktopNotification(deviceData) {
        debugMessage("parseCooktopNotification");
        if (angular.isDefined(deviceData["Configuration"])) {
            parseConfiguration(deviceData["Configuration"]);
        }
        if (!angular.isDefined($scope.cookTopInfo) && !justFirstTime) {
            justFirstTime = true;
            init();
            justFirstTime = false;
        }
        if (angular.isDefined(deviceData["description"])) {
            $scope.cookTopInfo.description = deviceData["description"];
        }
        if (angular.isDefined(deviceData["id"])) {
            $scope.cookTopInfo.id = deviceData["id"];
        }

        if (angular.isDefined(deviceData["ConfigurationLink"])) {
            $scope.cookTopInfo.ConfigurationLink = deviceData["ConfigurationLink"];
        }
        if (angular.isDefined(deviceData["Diagnosis"])) {
            if (angular.isDefined(deviceData["Diagnosis"]["diagnosisStart"])) {
                $scope.cookTopInfo.Diagnosis.diagnosisStart = deviceData["Diagnosis"]["diagnosisStart"];
            }
            if ($scope.cookTopInfo.Diagnosis.diagnosisStart === "Ready") {
                if (!$scope.appAtForeground && ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE || $scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE)) {
                    dismissLoadingBar(COOKTOP_COMMANDS.smartCareDiagnosis);
                    $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE;
                    validateCurrentScreen('SmartCareNoErrorPage');
                }
            } else if ($scope.cookTopInfo.Diagnosis.diagnosisStart === "Run") {
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE;
                validateCurrentScreen('SmartCarePage');
            }
        }
        if (angular.isDefined(deviceData["EnergyConsumption"])) {
            $scope.cookTopInfo.EnergyConsumption = deviceData["EnergyConsumption"];
        }
        if (angular.isDefined(deviceData["InformationLink"])) {
            $scope.cookTopInfo.InformationLink = deviceData["InformationLink"];
        }
        if (angular.isDefined(deviceData["Mode"])) {
            if (angular.isDefined(deviceData["Mode"]["options"])) {
                deviceData["Mode"]["options"].forEach(function (value) {
                    parseCookTopInfoModeOptions(value);
                });
            }
        }
        if (angular.isDefined(deviceData["Operation"])) {
            if (angular.isDefined(deviceData["Operation"]["power"])) {
                $scope.cookTopInfo.Operation.power = deviceData["Operation"]["power"];
            }
            if (angular.isDefined(deviceData["Operation"]["kidsLock"])) {
                $scope.cookTopInfo.Operation.kidsLock = deviceData["Operation"]["kidsLock"];
            }
        }
        if (angular.isDefined(deviceData["connected"])) {
            $scope.cookTopInfo.connected = deviceData["connected"];
        }
        if (angular.isDefined(deviceData["name"])) {
            $scope.cookTopInfo.name = deviceData["name"];
        }
        if (angular.isDefined(deviceData["resources"])) {
            $scope.cookTopInfo.resources = deviceData["resources"];
            deviceData["resources"].forEach(function (value) {
                if ($scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9300K-/AA1' || $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9300K-/AA2'
                        || $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9300K-/AA3' || $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9300K-/AA4') {
                    if (value.indexOf("Diagnosis") !== -1) {
                        $scope.showSmartCare = true;
                    }
                }
            });
        }
        if (angular.isDefined(deviceData["type"])) {
            $scope.cookTopInfo.type = deviceData["type"];
        }
        if (angular.isDefined(deviceData["uuid"])) {
            $scope.cookTopInfo.uuid = deviceData["uuid"];
        }

        if (angular.isDefined(deviceData["Alarms"])) {
            deviceData["Alarms"].forEach(function (value) {
                parseCookTopInfoAlarm(value);
            });
        }
    }

    function parseHoodNotification(deviceData) {
        return; //no need to update hood data when inside cooktop
        debugMessage("parseHoodNotification");
        if (angular.isDefined(deviceData["Configuration"])) {
            parseConfiguration(deviceData["Configuration"]);
        }
        if (angular.isDefined(deviceData["description"])) {
            $scope.HoodInfo.description = deviceData["description"];
        }
        if (angular.isDefined(deviceData["id"])) {
            $scope.HoodInfo.id = deviceData["id"];
        }
        if (angular.isDefined(deviceData["Alarms"])) {
            if (angular.isDefined(deviceData["Alarms"][0])) {
                if (angular.isDefined(deviceData["Alarms"][0]["id"])) {
                    $scope.HoodInfo.Alarms[0].id = deviceData["Alarms"][0]["id"];
                }
                if (angular.isDefined(deviceData["Alarms"][0]["code"])) {
                    $scope.HoodInfo.Alarms[0].code = deviceData["Alarms"][0]["code"];
                }
                if (angular.isDefined(deviceData["Alarms"][0]["alarmType"])) {
                    $scope.HoodInfo.Alarms[0].alarmType = deviceData["Alarms"][0]["alarmType"];
                }
                if (angular.isDefined(deviceData["Alarms"][0]["triggeredTime"])) {
                    $scope.HoodInfo.Alarms[0].triggeredTime = deviceData["Alarms"][0]["triggeredTime"];
                }
            }
        }
        if (angular.isDefined(deviceData["ConfigurationLink"])) {
            $scope.HoodInfo.ConfigurationLink = deviceData["ConfigurationLink"];
        }
        if (angular.isDefined(deviceData["Diagnosis"])) {
            if (angular.isDefined(deviceData["Diagnosis"]["diagnosisStart"])) {
                $scope.HoodInfo.Diagnosis.diagnosisStart = deviceData["Diagnosis"]["diagnosisStart"];
            }
            if ($scope.HoodInfo.Diagnosis.diagnosisStart === "Ready") {
                if (!$scope.appAtForeground && ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE || $scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE)) {
                    dismissLoadingBar(COOKTOP_COMMANDS.smartCareDiagnosis);
                    $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE;
                    validateCurrentScreen('SmartCareNoErrorPage');
                }
            } else if ($scope.HoodInfo.Diagnosis.diagnosisStart === "Run") {
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE;
                validateCurrentScreen('SmartCarePage');
            }
        }
        if (angular.isDefined(deviceData["EnergyConsumption"])) {
            $scope.HoodInfo.EnergyConsumption = deviceData["EnergyConsumption"];
        }
        if (angular.isDefined(deviceData["InformationLink"])) {
            $scope.HoodInfo.InformationLink = deviceData["InformationLink"];
        }
        if (angular.isDefined(deviceData["Mode"])) {
            if (angular.isDefined(deviceData["Mode"]["options"])) {
                deviceData["Mode"]["options"].forEach(function (value) {
                    parseHoodInfoModeOptions(value);
                });
            }
        }
        if (angular.isDefined(deviceData["Operation"])) {
            if (angular.isDefined(deviceData["Operation"]["power"])) {
                dismissLoadingBar(COOKTOP_COMMANDS.hoodPower);
                if (($scope.HoodInfo.Operation.power !== deviceData["Operation"]["power"]) && deviceData["Operation"]["power"] === 'Off') {
                    showToast($scope.translation.WEBMOB_device_hood_off);
                }
                $scope.HoodInfo.Operation.power = deviceData["Operation"]["power"];
                $scope.hoodOff = $scope.HoodInfo.Operation.power === 'Off' ? true : false;
                $scope.selectedFanValue = ($scope.HoodInfo.Operation.power === 'on' && !$scope.appAtForeground) ? 1 : $scope.selectedFanValue;
                setLightStatus();
            }
        }
        if (angular.isDefined(deviceData["connected"])) {
            $scope.HoodInfo.connected = deviceData["connected"];
            //$scope.cTopTabSelected = true;
        }
        if (angular.isDefined(deviceData["Device"])) {
            if (angular.isDefined(deviceData["Device"]["connected"])) {
                $scope.HoodInfo.connected = deviceData["Device"]["connected"];
                //$scope.cTopTabSelected = true;
            }
        }
        if (angular.isDefined(deviceData["name"])) {
            $scope.HoodInfo.name = deviceData["name"];
        }
        if (angular.isDefined(deviceData["resources"])) {
            $scope.HoodInfo.resources = deviceData["resources"];
            deviceData["resources"].forEach(function (value) {
                if ($scope.HoodInfo.Mode.options[0].DeviceType === 'NV9300K-/AA1' || $scope.HoodInfo.Mode.options[0].DeviceType === 'NV9300K-/AA2'
                        || $scope.HoodInfo.Mode.options[0].DeviceType === 'NV9300K-/AA3' || $scope.HoodInfo.Mode.options[0].DeviceType === 'NV9300K-/AA4') {
                    if (value.indexOf("Diagnosis") !== -1) {
                        $scope.showSmartCare = true;
                    }
                }
            });
        }
//        if (angular.isDefined(deviceData["resources"])) {
//            $scope.HoodInfo.resources = deviceData["resources"];
//        }
        if (angular.isDefined(deviceData["type"])) {
            $scope.HoodInfo.type = deviceData["type"];
        }
        if (angular.isDefined(deviceData["uuid"])) {
            $scope.HoodInfo.uuid = deviceData["uuid"];
        }

    }

    function parseCookTopInfoAlarm(Alarm) {
        if (angular.isDefined(Alarm)) {
            var id = Alarm["id"];
            if (angular.isDefined(id)) {
                if (angular.isDefined(Alarm["id"])) {
                    $scope.cookTopInfo.Alarms[id].id = Alarm["id"];
                }
                if (angular.isDefined(Alarm["code"])) {
                    $scope.cookTopInfo.Alarms[id].code = Alarm["code"];
                    $scope.cookTopBurnerArray[id].AlarmCode = Alarm["code"];
                    if ($scope.cookTopInfo.Alarms[0].code.indexOf("CT_E") !== -1) {
                        $scope.errorCode = getErrorCode($scope.cookTopInfo.Alarms[0].code);
//                        if ($scope.errorCode !== '') {
//                            debugMessage('idOne errorRemoved false');
//                            errorRemoved = false;
//                        }
                    }
                    if ($scope.cookTopInfo.Alarms[id].code.indexOf("NoPanDetect") !== -1) {
                        var tmpBurnerId = Number($scope.cookTopInfo.Alarms[id].code.charAt($scope.cookTopInfo.Alarms[0].code.length - 1));
                        debugMessage("No pan alarm for burner " + tmpBurnerId);
                        /*
                         * No pan detected make operation state as ready for all burners except flux area
                         */
                        if (!isNaN(tmpBurnerId) && tmpBurnerId < 6) {
                            if ($scope.leftFlex && tmpBurnerId > 1) {
                                //$scope.cookTopBurnerArray[tmpBurnerId].OperationState = 'Ready';
                            }
                        }
                        showToast($scope.translation.WEBMOB_device_cooktop_no_pan_detect_popup);
                    }
                }
                if (angular.isDefined(Alarm["alarmType"])) {
                    $scope.cookTopInfo.Alarms[id].alarmType = Alarm["alarmType"];
                }
                if (angular.isDefined(Alarm["triggeredTime"])) {
                    $scope.cookTopInfo.Alarms[id].triggeredTime = Alarm["triggeredTime"];
                }
            }
        }
    }

    function parseCookTopInfoModeOptions(modeOptionData) {
        if (modeOptionData.indexOf("DeviceType") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DeviceType = modeOptionData.split("_")[1];
            $scope.supportHrTimer = $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9500M-/AA0' || $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9500M-/AA1' || $scope.cookTopInfo.Mode.options[0].DeviceType === 'NV9500M-/KO0';
            timerMaxValue = $scope.supportHrTimer ? 780 : 99;
        }
        if (modeOptionData.indexOf("OperationType") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationType = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("Bluetooth") !== -1) {
            $scope.HoodInfo.Mode.options[0].Bluetooth = modeOptionData.split("_")[1];
            $scope.cTopTabSelected = true;
        }
        if (modeOptionData.indexOf("hood") !== -1) {
            $scope.HoodInfo.Mode.options[0].Hood = (modeOptionData.split("_")[1]).toLowerCase();
        }
        if (modeOptionData.indexOf("FanSpeed") !== -1) {
            $scope.HoodInfo.Mode.options[0].FanSpeed = Number(modeOptionData.split("_")[1]);
            $scope.selectedFanValue = $scope.HoodInfo.Mode.options[0].FanSpeed;
            setFanStatus($scope.selectedFanValue);
        }
        if (modeOptionData.indexOf("Lamp") !== -1) {
            $scope.HoodInfo.Mode.options[0].Lamp = modeOptionData.split("_")[1];
            $scope.hoodLight = $scope.HoodInfo.Mode.options[0].Lamp === 'On' ? true : false;
            setLightStatus();
        }
        if (modeOptionData.indexOf("OperationType") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationType = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("MainTimerCurrent") !== -1) {
            var val = Number(modeOptionData.split("_")[1]);
            var timerValue = val;
            if ($scope.supportHrTimer) {
                timerValue = Math.floor(val / 60);
                if (0 < val && val < 60) {
                    timerValue = 1;
                }
            }

            $scope.cookTopInfo.Mode.options[0].MainTimerCurrent = timerValue;
            $scope.kitchenTimer = $scope.appAtForeground ? $scope.kitchenTimer : timerValue;
            kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", tab: 1});
            updateTimerValue($scope.kitchenTimer);
            if ($scope.cookTopInfo.Mode.options[0].MainTimerState === 'Run') {
                dismissLoadingBar(COOKTOP_COMMANDS.kitchenTimer);
            }
            if ($scope.cookTopInfo.Mode.options[0].MainTimerCurrent === 0 && $scope.cookTopInfo.Mode.options[0].MainTimerState !== 'Ready') {
                $scope.focuseRemoved = true;
            }
        }
        if (modeOptionData.indexOf("MainTimerSet") !== -1) {
            var val = Number(modeOptionData.split("_")[1]);
            var timerValue = val;
            if ($scope.supportHrTimer) {
                timerValue = Math.floor(val / 60);
                if (0 < val && val < 60) {
                    timerValue = 1;
                }
            }
            $scope.cookTopInfo.Mode.options[0].MainTimerSet = Number(modeOptionData.split("_")[1]);
            //$scope.kitchenTimer = $scope.appAtForeground || $scope.cookTopInfo.Mode.options[0].MainTimerSet <= 0 ? $scope.kitchenTimer : timerValue;
            //$scope.kitchenTimer = $scope.kitchenTimer <= 0 ? $scope.cookTopInfo.Mode.options[0].MainTimerCurrent : $scope.kitchenTimer;
            //$scope.cookTopInfo.Mode.options[0].MainTimerCurrent = $scope.kitchenTimer;
            //kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", tab: 1});
            //updateTimerValue($scope.kitchenTimer);
            if ($scope.cookTopInfo.Mode.options[0].MainTimerState === 'Run') {
                dismissLoadingBar(COOKTOP_COMMANDS.kitchenTimer);
            }
        }
        if (modeOptionData.indexOf("MainTimerState") !== -1) {
            if ($scope.cookTopInfo.Mode.options[0].MainTimerState !== modeOptionData.split("_")[1]) {
                blurInputBox('kitchenTimer');
            }
            $scope.cookTopInfo.Mode.options[0].MainTimerState = modeOptionData.split("_")[1];
            dismissLoadingBar(COOKTOP_COMMANDS.kitchenTimer);
            if ($scope.cookTopInfo.Mode.options[0].MainTimerState === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_TIMER_FINISH, '', $scope.translation.WEBMOB_device_cooktop_downcount_timer_popup, $scope.translation.WEBMOB_common_ok, '');
            }
            if (!$scope.appAtForeground) {
                if ($scope.cookTopInfo.Mode.options[0].MainTimerState === 'Run') {
                    $scope.KitchenTimerState = 'Run';
                    $scope.startStopState = $scope.translation.WEBMOB_common_cooktop_pause;
                } else if ($scope.cookTopInfo.Mode.options[0].MainTimerState === 'Pause') {
                    $scope.KitchenTimerState = 'Pause';
                    $scope.startStopState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;//'PAUSE'
                } else {
                    $scope.KitchenTimerState = 'Ready';
                    $scope.startStopState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
                }
            }
        }
        if (modeOptionData.indexOf("Pause") !== -1) {
            $scope.cookTopInfo.Mode.options[0].Pause = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("SyncFlex") !== -1) {
            $scope.cookTopInfo.Mode.options[0].SyncFlex = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("FlexCoilRight") !== -1
                || modeOptionData.indexOf("UserFlexCoilRight") !== -1) {
            $scope.cookTopInfo.Mode.options[0].FlexCoilValueRight = modeOptionData.split("_")[1];
            parseFlexCoilOnOffInfoRight();
        }
        if (modeOptionData.indexOf("FlexCoil_") !== -1
                || modeOptionData.indexOf("UserFlexCoilLeft") !== -1) {
            $scope.cookTopInfo.Mode.options[0].FlexCoilValue = modeOptionData.split("_")[1];
            parseFlexCoilOnOffInfo();
        }
        if (modeOptionData.indexOf("OperationState0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState0);
        }

        if (modeOptionData.indexOf("PanSize0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize0);
        }
        if (modeOptionData.indexOf("PanSize1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize1);
        }
        if (modeOptionData.indexOf("PanSize2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize2);
        }
        if (modeOptionData.indexOf("PanSize3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize3);
        }
        if (modeOptionData.indexOf("PanSize4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize4);
        }
        if (modeOptionData.indexOf("PanSize5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PanSize5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].PanSize = parsePanSize($scope.cookTopInfo.Mode.options[0].PanSize5);
        }

        if (modeOptionData.indexOf("OperationState1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState1);
        }
        if (modeOptionData.indexOf("OperationState2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState2);
        }
        if (modeOptionData.indexOf("OperationState3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState3);
        }
        if (modeOptionData.indexOf("OperationState4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState4);
        }
        if (modeOptionData.indexOf("OperationState5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState5);
        }
        if (modeOptionData.indexOf("OperationState6") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState6 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[6].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState6);
        }
        if (modeOptionData.indexOf("OperationState7") !== -1) {
            $scope.cookTopInfo.Mode.options[0].OperationState7 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[7].OperationState = parseOperationState($scope.cookTopInfo.Mode.options[0].OperationState7);
        }

        if (modeOptionData.indexOf("HotSurface0-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface0_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface0_1);
        }
        if (modeOptionData.indexOf("HotSurface1-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface1_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface1_1);
        }
        if (modeOptionData.indexOf("HotSurface2-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface2_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface2_1);
        }
        if (modeOptionData.indexOf("HotSurface3-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface3_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface3_1);
        }
        if (modeOptionData.indexOf("HotSurface4-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface4_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface4_1);
        }
        if (modeOptionData.indexOf("HotSurface5-1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface5_1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].HotSurface_1 = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface5_1);
        }

        if (modeOptionData.indexOf("HotSurface0_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface0);
        }
        if (modeOptionData.indexOf("HotSurface1_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface1);
        }
        if (modeOptionData.indexOf("HotSurface2_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface2);
        }
        if (modeOptionData.indexOf("HotSurface3_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface3);
        }
        if (modeOptionData.indexOf("HotSurface4_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface4);
        }
        if (modeOptionData.indexOf("HotSurface5_") !== -1) {
            $scope.cookTopInfo.Mode.options[0].HotSurface5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].HotSurface = parseHotSurface($scope.cookTopInfo.Mode.options[0].HotSurface5);
        }

        if (modeOptionData.indexOf("PowerLevel0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel0);
        }
        if (modeOptionData.indexOf("PowerLevel1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel1);
        }
        if (modeOptionData.indexOf("PowerLevel2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel2);
        }
        if (modeOptionData.indexOf("PowerLevel3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel3);
        }
        if (modeOptionData.indexOf("PowerLevel4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel4);
        }
        if (modeOptionData.indexOf("PowerLevel5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].PowerLevel5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].PowerLevel = parsePowerLevel($scope.cookTopInfo.Mode.options[0].PowerLevel5);
        }

        if (modeOptionData.indexOf("TimerState0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState0);
            if ($scope.cookTopInfo.Mode.options[0].TimerState0 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }
        if (modeOptionData.indexOf("TimerState1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState1);
            if ($scope.cookTopInfo.Mode.options[0].TimerState1 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }
        if (modeOptionData.indexOf("TimerState2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState2);
            if ($scope.cookTopInfo.Mode.options[0].TimerState2 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }
        if (modeOptionData.indexOf("TimerState3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState3);
            if ($scope.cookTopInfo.Mode.options[0].TimerState3 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }
        if (modeOptionData.indexOf("TimerState4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState4);
            if ($scope.cookTopInfo.Mode.options[0].TimerState4 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }
        if (modeOptionData.indexOf("TimerState5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].TimerState5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].TimerState = parseTimerState($scope.cookTopInfo.Mode.options[0].TimerState5);
            if ($scope.cookTopInfo.Mode.options[0].TimerState5 === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_title, $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer_finish_popup_description, $scope.translation.WEBMOB_common_ok, '');
            }
        }

        if (modeOptionData.indexOf("ch0_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking0 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[0].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking0);
            $scope.cookTopBurnerArray[0].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[0].GuidedCooking);
        }
        if (modeOptionData.indexOf("ch1_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking1 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[1].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking1);
            $scope.cookTopBurnerArray[1].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[1].GuidedCooking);
        }
        if (modeOptionData.indexOf("ch2_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking2 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[2].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking2);
            $scope.cookTopBurnerArray[2].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[2].GuidedCooking);
        }
        if (modeOptionData.indexOf("ch3_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking3 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[3].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking3);
            $scope.cookTopBurnerArray[3].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[3].GuidedCooking);
        }
        if (modeOptionData.indexOf("ch4_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking4 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[4].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking4);
            $scope.cookTopBurnerArray[4].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[4].GuidedCooking);
        }
        if (modeOptionData.indexOf("ch5_guided_cooking") !== -1) {
            $scope.cookTopInfo.Mode.options[0].GuidedCooking5 = modeOptionData.split("_")[3];
            $scope.cookTopBurnerArray[5].GuidedCooking = parseGuidedCooking($scope.cookTopInfo.Mode.options[0].GuidedCooking5);
            $scope.cookTopBurnerArray[5].GuidedCookingImage = parseGuidedCookingImage($scope.cookTopBurnerArray[5].GuidedCooking);
        }

        if (modeOptionData.indexOf("DownCountTimerCurrent0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent0);
        }
        if (modeOptionData.indexOf("DownCountTimerCurrent1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent1);
        }
        if (modeOptionData.indexOf("DownCountTimerCurrent2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent2);
        }
        if (modeOptionData.indexOf("DownCountTimerCurrent3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent3);
        }
        if (modeOptionData.indexOf("DownCountTimerCurrent4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent4);
        }
        if (modeOptionData.indexOf("DownCountTimerCurrent5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].DownCountTimerCurrent = parseDownCountTimerCurrent($scope.cookTopInfo.Mode.options[0].DownCountTimerCurrent5);
        }

        if (modeOptionData.indexOf("DownCountTimerSet0") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet0 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[0].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet0);
        }
        if (modeOptionData.indexOf("DownCountTimerSet1") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet1 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[1].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet1);
        }
        if (modeOptionData.indexOf("DownCountTimerSet2") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet2 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[2].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet2);
        }
        if (modeOptionData.indexOf("DownCountTimerSet3") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet3 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[3].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet3);
        }
        if (modeOptionData.indexOf("DownCountTimerSet4") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet4 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[4].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet4);
        }
        if (modeOptionData.indexOf("DownCountTimerSet5") !== -1) {
            $scope.cookTopInfo.Mode.options[0].DownCountTimerSet5 = modeOptionData.split("_")[1];
            $scope.cookTopBurnerArray[5].DownCountTimerSet = parseDownCountTimerSet($scope.cookTopInfo.Mode.options[0].DownCountTimerSet5);
        }
        if (modeOptionData.indexOf("TimerS") !== -1) {
            dismissLoadingBar(COOKTOP_COMMANDS.BurnerTimer);
        }
    }

    function parseFlexCoilOnOffInfo() {
        var binaryVal = readCooktopValue(Number($scope.cookTopInfo.Mode.options[0].FlexCoilValue), 4);
        $scope.flexCoilStatus[0].FlexOn = binaryVal[3] === '1' ? true : false;
        $scope.flexCoilStatus[1].FlexOn = binaryVal[2] === '1' ? true : false;
        $scope.flexCoilStatus[2].FlexOn = binaryVal[1] === '1' ? true : false;
        $scope.flexCoilStatus[3].FlexOn = binaryVal[0] === '1' ? true : false;
    }

    function parseFlexCoilOnOffInfoRight() {
        var binaryVal = readCooktopValue(Number($scope.cookTopInfo.Mode.options[0].FlexCoilValueRight), 4);
        $scope.flexCoilStatus[4].FlexOn = binaryVal[3] === '1' ? true : false;
        $scope.flexCoilStatus[5].FlexOn = binaryVal[2] === '1' ? true : false;
        $scope.flexCoilStatus[6].FlexOn = binaryVal[1] === '1' ? true : false;
        $scope.flexCoilStatus[7].FlexOn = binaryVal[0] === '1' ? true : false;
    }

    function parseHoodInfoModeOptions(modeOptionData) {
        if (modeOptionData.indexOf("DeviceType") !== -1) {
            $scope.HoodInfo.Mode.options[0].DeviceType = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("Bluetooth") !== -1) {
            $scope.HoodInfo.Mode.options[0].Bluetooth = modeOptionData.split("_")[1];
            //$scope.cTopTabSelected = true;
        }
        if (modeOptionData.indexOf("hood") !== -1) {
            $scope.HoodInfo.Mode.options[0].Hood = (modeOptionData.split("_")[1]).toLowerCase();
        }
        if (modeOptionData.indexOf("BTState") !== -1) {
            $scope.HoodInfo.Mode.options[0].BTState = Number(modeOptionData.split("_")[1]);
        }
        if (modeOptionData.indexOf("AutoMode") !== -1) {
            $scope.HoodInfo.Mode.options[0].AutoMode = modeOptionData.split("_")[1];
        }
        if (modeOptionData.indexOf("FanSpeed") !== -1) {
            $scope.HoodInfo.Mode.options[0].FanSpeed = Number(modeOptionData.split("_")[1]);
            $scope.selectedFanValue = $scope.HoodInfo.Mode.options[0].FanSpeed;
            setFanStatus($scope.selectedFanValue);
            dismissLoadingBar(COOKTOP_COMMANDS.hoodFan);
        }
        if (modeOptionData.indexOf("Lamp") !== -1) {
            $scope.HoodInfo.Mode.options[0].Lamp = modeOptionData.split("_")[1];
            $scope.hoodLight = $scope.HoodInfo.Mode.options[0].Lamp === 'On' ? true : false;
            setLightStatus();
            dismissLoadingBar(COOKTOP_COMMANDS.hoodLight);
        }
        if (modeOptionData.indexOf("ShutOffTimerState") !== -1) {
            if ($scope.HoodInfo.Mode.options[0].ShutOffTimerState !== modeOptionData.split("_")[1]) {
                blurInputBox('hoodTimer');
            }
            $scope.HoodInfo.Mode.options[0].ShutOffTimerState = modeOptionData.split("_")[1];
            dismissLoadingBar(COOKTOP_COMMANDS.hoodTimer);
            if ($scope.HoodInfo.Mode.options[0].ShutOffTimerState === 'Finish' && !justFirstTime && !$scope.appAtForeground) {
                showcustDialog(COOKTOP_ALERT_STATE.ALERT_HOOD_TIMER_FINISH, '', $scope.translation.WEBMOB_device_hood_time_left_guide, $scope.translation.WEBMOB_common_ok, '');
            }
            if (!$scope.appAtForeground) {
                if ($scope.HoodInfo.Mode.options[0].ShutOffTimerState === 'Run') {
                    $scope.HoodTimerState = 'Run';
                    $scope.startStopHoodState = $scope.translation.WEBMOB_device_hood_stop_button;
                    $scope.timerStopTextHood = ($scope.hoodTimer < 1) ? $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1 : $scope.translation.WEBMOB_device_hood_set_time_guide4;
                } else {
                    $scope.HoodTimerState = 'Ready';
                    $scope.startStopHoodState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
                }
            }
        }
        if (modeOptionData.indexOf("ShutOffTimerCurrent") !== -1) {
            var val = Number(modeOptionData.split("_")[1]);
            var timerValue = val;
            if ($scope.supportHrTimer) {
                timerValue = Math.floor(val / 60);
                if (0 < val && val < 60) {
                    timerValue = 1;
                }
            }
            $scope.hoodTimer = $scope.appAtForeground || $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent <= 0 ? $scope.hoodTimer : timerValue;
            $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent = timerValue;
            hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
            updateHoodTimerValue($scope.hoodTimer);
            if ($scope.HoodInfo.Mode.options[0].ShutOffTimerState === 'Run') {
                dismissLoadingBar(COOKTOP_COMMANDS.hoodTimer);
            }
            if ($scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent === 0 && $scope.HoodInfo.Mode.options[0].ShutOffTimerState !== 'Ready') {
                $scope.focuseRemoved = true;
            }
        }
        if (modeOptionData.indexOf("ShutOffTimerSet") !== -1) {
            var shutOffTimerVal = Number(modeOptionData.split("_")[1]);
            //$scope.hoodTimer = $scope.appAtForeground || $scope.HoodInfo.Mode.options[0].ShutOffTimerSet <= 0 ? $scope.hoodTimer : shutOffTimerVal;
            $scope.HoodInfo.Mode.options[0].ShutOffTimerSet = shutOffTimerVal;
            //$scope.hoodTimer = $scope.hoodTimer <= 0 ? $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent : $scope.hoodTimer;
            //$scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent = $scope.hoodTimer;
            //hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
            //updateHoodTimerValue($scope.hoodTimer);
            if ($scope.HoodInfo.Mode.options[0].ShutOffTimerState === 'Run') {
                dismissLoadingBar(COOKTOP_COMMANDS.hoodTimer);
            }
        }
    }

    function parsePanSize(value) {
        return value;
    }

    function parseOperationState(value) {
        return value;
    }

    function parseHotSurface(value) {
        if (value.indexOf('-') !== -1) {
            value = value.replace(/-/, /./);
        }
        return value;
    }

    function parsePowerLevel(value) {
        if (value.indexOf('-') !== -1) {
            value = value.replace(/-/, /./);
        }
        return value;
    }

    function parseTimerState(value) {
        return value;
    }

    function parseDownCountTimerCurrent(value) {
        if (0 < value && value < 60) {
            value = 60;
        }
        return value;
    }

    function parseDownCountTimerSet(value) {
        return value;
    }

    function parseGuidedCooking(value) {
        return Number(value);
    }

    function parseGuidedCookingImage(id) {
        if (id > 0) {
            return $scope.CooktopRecipes[(id - 1)].image;
        }
        return '';
    }

    function handleStatusCode(status) {
        if (status === 204) {
            //loadingValues();
        }
    }

    function readChildValue(id) {
        return ($scope.DeviceModelName === 'NV9500M-/AA0' && ((id & 1) === 1));
    }

    function readCooktopValue(value, length) {
        var binaryArray, getStrCopy = function (str, copies) {
            var newStr = str;
            copies = (copies > 0) ? copies : 1;
            while (--copies) {
                newStr += str;
            }
            return newStr;
        },
                convertDecToBase = function (dec, base, length, padding) {
                    padding = padding || '0';
                    var num = dec.toString(base);
                    length = length || num.length;
                    if (num.length !== length) {
                        if (num.length < length) {
                            num = getStrCopy(padding, (length - num.length)) + num;
                        }
                    }
                    return num;
                };
        return binaryArray = convertDecToBase(Number(value), 2, length).split('');
    }

    function requestFailHandler(response) {
        debugMessage(JSON.stringify(response));
        $scope.loadingBar = false;
        $scope.checkResponse = [];
    }

    function showConnectionFailurePopup() {
        if (isTextInput(document.activeElement)) {
            document.activeElement.blur();
        }
        showcustDialog(COOKTOP_ALERT_STATE.ALERT_CONNECTION_ERROR, $scope.translation.WEBMOB_device_range_alarm_connection_failure_title, $scope.translation.WEBMOB_common_check_power_and_network, '', $scope.translation.WEBMOB_common_ok);
    }

    function closeConnectionFailurePopup() {
        $scope.showFullScreenPopup = false;
    }

    function preConditionValidation(screen) {
        $scope.showKitchenTimer = false;
        $scope.showHoodTimer = false;
        $scope.showBurnerTimerPage = false;
        $scope.settingOption = false;
        $scope.aboutOption = true;
        $scope.showHelpOption = false;
        $scope.moreOptionVisible = false;
        doNotChangeScreen = false;
        $scope.supportHrTimer = ($scope.DeviceModelName === 'NV9500M-/AA0' || $scope.DeviceModelName === 'NV9500M-/AA1' || $scope.DeviceModelName === 'NV9500M-/KO0') && $scope.cTopTabSelected;
        if (angular.isDefined($state.current) && angular.isDefined($state.current) && screen !== $state.current.name) {
            scroll_middle_area.scrollTop = 0;
        }
    }

    $scope.$on('$viewContentLoaded', function () {
        debugMessage("$viewContentLoaded " + $scope.currentScreen);
        if ($scope.currentScreen !== COOKTOP_SCREENS.COOKTOP_MAIN_LOADING_PAGE) {
            $scope.mainLoadingScreen = true;
        }
        if ($scope.currentScreen !== COOKTOP_SCREENS.COOKTOP_BURNER_HOME_PAGE && $scope.currentScreen !== COOKTOP_SCREENS.COOKTOP_MAIN_LOADING_PAGE) {
            selectBurner(-1);
        }
        switch ($scope.currentScreen) {
            case COOKTOP_SCREENS.COOKTOP_MAIN_LOADING_PAGE:
                $scope.mainLoadingScreen = false;
                break;
            case COOKTOP_SCREENS.COOKTOP_BURNER_HOME_PAGE:
                $scope.moreOptionVisible = true;
                $scope.TabsVisibleAtPage = $scope.showHood; //show hood as as seperate device UI 2.0 
                $scope.headerBarVisible = true;
                $scope.showHelpOption = true;
                $scope.deviceName = $scope.translation.WEBMOB_common_device_cooktop;
                $scope.mainPageDetailFUG = getLocalStorageData("maincTopPageFUG");
                if (!$scope.mainPageDetailFUG) {
                    $scope.cTopPageFUG = true;
                    setLocalStorageData("maincTopPageFUG", true);
                }
                break;
            case COOKTOP_SCREENS.COOKTOP_KITCHEN_TIMER_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_device_cooktop_kitchen_timer;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                $scope.showKitchenTimer = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_BURNER_TIMER_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_device_us_cooktop_set_burner_timer;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                $scope.showBurnerTimerPage = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_HOOD_TIMER_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_device_hood_set_timer;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                $scope.showHoodTimer = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_ERROR_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_device_range_comm_error;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                $scope.showMenuOptionPopup = false;
                $scope.showFullScreenPopup = false;
                doNotChangeScreen = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_SETTING_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_common_settings;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_RECIPE_LIST_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_device_us_cooktop_recipe;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_RECIPE_INGREDIENT_PAGE:
                $scope.deviceName = $scope.RecipeIngredientTilte;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_ABOUT_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_common_about_device;
                $scope.headerBarVisible = true;
                $scope.TabsVisibleAtPage = false;
                doNotChangeScreen = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_common_self_diagnosis;
                $scope.TabsVisibleAtPage = false;
                $scope.headerBarVisible = true;
                changeSmartCarePage = true;
                break;
            case COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE:
                $scope.deviceName = $scope.translation.WEBMOB_common_self_diagnosis;
                $scope.TabsVisibleAtPage = false;
                $scope.headerBarVisible = true;
                changeSmartCarePage = true;
                break;
            default :
                debugMessage("validate screen else part: " + $scope.currentScreen);
                break;
        }
    });

    function validateCurrentScreen(screen) {
        preConditionValidation(screen);
        switch (screen) {
            case 'BurnerHomePage':
                debugMessage("validate screen : " + screen + " show tab : " + $scope.showHood);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_BURNER_HOME_PAGE;
                $scope.showHelpOption = true;
                $scope.moreOptionVisible = true;
                $scope.TabsVisibleAtPage = $scope.showHood;
                $scope.kitchenTimer = Number($scope.cookTopInfo.Mode.options[0].MainTimerCurrent);
                $scope.hoodTimer = $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent;
                $scope.cookTopBurnerPause = checkPauseState();
                if ($scope.supportHrTimer) {
                    var kitchenHr = Math.floor($scope.kitchenTimer / 60);
                    var kitchenMin = Math.floor($scope.kitchenTimer % 60);
                    var hoodHr = Math.floor($scope.hoodTimer / 60);
                    var hoodMin = Math.floor($scope.hoodTimer % 60);
                    var timeKitchen = kitchenHr > 0 ? kitchenHr + $scope.translation.WEBMOB_device_range_comm_hr + " " + (kitchenMin > 9 ? kitchenMin : '0' + kitchenMin) : $scope.kitchenTimer;
                    var timeHood = hoodHr > 0 ? hoodHr + $scope.translation.WEBMOB_device_range_comm_hr + " " + (hoodMin > 9 ? hoodMin : '0' + hoodMin) : $scope.hoodTimer;
                } else {
                    var timeKitchen = $scope.kitchenTimer;
                    var timeHood = $scope.hoodTimer;
                }
                $scope.kitchenTimerLeftTime = Number($scope.kitchenTimer) > 1 ? $scope.translation.WEBMOB_device_cooktop_timer_left2.replace(/#1#/, timeKitchen) : $scope.translation.WEBMOB_device_cooktop_timer_left.replace(/#1#/, timeKitchen);
                $scope.hoodTimerLeftTime = Number($scope.hoodTimer) > 1 ? $scope.translation.WEBMOB_device_cooktop_timer_left2.replace(/#1#/, timeHood) : $scope.translation.WEBMOB_device_cooktop_timer_left.replace(/#1#/, timeHood);
                $state.transitionTo('BurnerHomePage');
                break;
            case 'KitchenTimerPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_KITCHEN_TIMER_PAGE;
                roundShape = kitchenTimerDrag;
                $scope.cookTopBurnerPause = checkPauseState();
                $state.transitionTo('KitchenTimerPage');
                document.getElementById("kitchenTimerId").style.zIndex = 1;
                $scope.showKitchenTimer = true;
                break;
            case 'BurnerTimerPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_BURNER_TIMER_PAGE;
                roundShape = burnerTimerDrag;
                $scope.cookTopBurnerPause = checkPauseState();
                $state.transitionTo('BurnerTimerPage');
                document.getElementById("burnerTimerId").style.zIndex = 1;
                $scope.showBurnerTimerPage = true;
                break;
            case 'HoodTimerPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_HOOD_TIMER_PAGE;
                roundShape = hoodTimerDrag;
                $scope.cookTopBurnerPause = checkPauseState();
                $state.transitionTo('HoodTimerPage');
                document.getElementById("hoodTimerId").style.zIndex = 1;
                $scope.showHoodTimer = true;
                break;
            case 'ErrorPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_ERROR_PAGE;
                $state.transitionTo('ErrorPage');
                break;
            case 'SettingPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SETTING_PAGE;
                $state.transitionTo('SettingPage');
                break;
            case 'RecipeListPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_RECIPE_LIST_PAGE;
                $scope.deviceName = $scope.translation.WEBMOB_device_us_cooktop_recipe;
                $state.transitionTo('RecipeListPage');
                break;
            case 'RecipeIngredientPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_RECIPE_INGREDIENT_PAGE;
                $state.transitionTo('RecipeIngredientPage');
                break;
            case 'AboutPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_ABOUT_PAGE;
                $state.transitionTo('AboutPage');
                break;
            case 'SmartCarePage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE;
                $state.transitionTo('SmartCarePage');
                break;
            case 'SmartCareNoErrorPage':
                debugMessage("validate screen : " + screen);
                $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE;
                $state.transitionTo('SmartCareNoErrorPage');
                break;
            default :
                debugMessage("validate screen else part: " + screen);
                break;
        }
    }

    function noScroll() {
        return ($scope.showFullScreenPopup || $scope.showMenuOptionPopup || $scope.samrtControlPopup
                || $scope.hoodPageFUG || $scope.cTopPageFUG
                || $scope.loadingBar || !$scope.mainLoadingScreen || $scope.showBurnerInfoPopup);
    }

    function fixScreen() {
        scroll_middle_area.style.overflowY = "hidden";
        scroll_middle_area.style.position = "fixed";
    }

    function scrollScreen() {
        //document.getElementById("bodyTag").style.pointerEvents = 'auto';
        scroll_middle_area.style.position = "absolute";
        scroll_middle_area.style.overflowY = "overlay";
    }

    function onBackPressedEvent(e) {
        //e.stopPropagation();
        onBackPressed();
    }

    function refreshValue() {
        debugMessage('All value reset');
    }

    function onBackPressed() {
        debugMessage("Back key pressed from : " + $scope.currentScreen);
        if ($scope.showFullScreenPopup || $scope.showMenuOptionPopup) {//any popup is open then close and return
            $scope.showFullScreenPopup && onAlertButton1Click();
            $scope.showMenuOptionPopup && hideMenuOption();
            if ($scope.alertState === 3) {
                closeApp();
            }
            return;
        }
        if ($scope.cTopPageFUG || $scope.hoodPageFUG) {
            closeUsageHelpPage();
            return;
        }

        refreshValue();
        switch ($scope.currentScreen) {
            case COOKTOP_SCREENS.COOKTOP_BURNER_HOME_PAGE:
            case COOKTOP_SCREENS.COOKTOP_ERROR_PAGE:
            case COOKTOP_SCREENS.COOKTOP_MAIN_LOADING_PAGE:
                closeApp();
                break;
            case COOKTOP_SCREENS.COOKTOP_RECIPE_LIST_PAGE:
            case COOKTOP_SCREENS.COOKTOP_KITCHEN_TIMER_PAGE:
                doNotChangeScreen = false;
                $scope.showKitchenTimer = false;
                $scope.cTopTabSelected = true;
                updateCookTopBurnerValues();
                validateCurrentScreen('BurnerHomePage');
                break;
            case COOKTOP_SCREENS.COOKTOP_RECIPE_INGREDIENT_PAGE:
                validateCurrentScreen('RecipeListPage');
                break;
            case COOKTOP_SCREENS.COOKTOP_HOOD_TIMER_PAGE:
                doNotChangeScreen = false;
                $scope.showHoodTimer = false;
                $scope.cTopTabSelected = false;
                validateCurrentScreen('BurnerHomePage');
                break;
            case COOKTOP_SCREENS.COOKTOP_BURNER_TIMER_PAGE:
                doNotChangeScreen = false;
                $scope.burnerTimer = null;
                $scope.showBurnerTimerPage = false;
                $scope.cTopTabSelected = true;
                validateCurrentScreen('BurnerHomePage');
                break;
            case COOKTOP_SCREENS.COOKTOP_SETTING_PAGE:
            case COOKTOP_SCREENS.COOKTOP_ABOUT_PAGE:
                doNotChangeScreen = false;
                showCurrentScreen();
                validateCurrentScreen('BurnerHomePage');
                break;
            case COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE://Fallthrough
            case COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE:
                validateCurrentScreen('AboutPage');
                break;
            default :
                debugMessage("Back key pressed from else " + $scope.currentScreen);
                //closeApp();
                break;
        }
    }

    function onAboutAction(reqParam) {
        if (reqParam === "smartcare") {
            $scope.currentScreen = COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE;
            validateCurrentScreen('SmartCarePage');
            return;
        }
        nativeInterface.runOnNative("customerService", aboutCommand(reqParam));
    }

    function cTopTabClick(id) {
        if ($scope.TabsVisibleAtPage) {
            if (id === 1) {
                $scope.cTopTabSelected = false;
            } else {
                $scope.cTopTabSelected = true;
            }
            showCurrentScreen();
        }
    }

    function hideMenuOption() {
        debugMessage('hideMenuOption');
        $scope.showMenuOptionPopup = false;
    }

    function showMenuOption() {
        debugMessage('showMenuOption');
        $scope.showMenuOptionPopup = true;
        $timeout(function () {
            document.getElementById("showMenufullScreenPopupId").style.zIndex = 999;
            document.getElementById("showMenuPopupDivId").style.zIndex = 999;
        }, 0);
    }

    function hideFanOption() {
        debugMessage('hideMenuOption');
        $scope.showFanOptionPopup = false;
    }

    function showFanOption() {
        debugMessage('showMenuOption');
        $scope.showFanOptionPopup = true;
        $timeout(function () {
            document.getElementById("fanModePopupId").style.zIndex = 999;
            document.getElementById("fanModePopupDivId").style.zIndex = 999;
        }, 0);
    }

    function hideBurnerInfoPopup() {
        debugMessage('hideBurnerInfoPopup');
        selectBurner(-1);
        $scope.showBurnerInfoPopup = false;
    }

    function hideRTopInfoPopup() {
        debugMessage('hideRTopInfoPopup');
        $scope.selectedRTopBurner = -1;
        $scope.showRTopInfoPopup = false;
    }

    function showBurnerInfoPopups() {
        debugMessage('showBurnerInfoPopups');
        $scope.showBurnerInfoPopup = true;
        $timeout(function () {
            document.getElementById("burnerInfoPopupId").style.zIndex = 999;
            document.getElementById("burnerInfoDivId").style.zIndex = 999;
        }, 0);
    }

    function showRTopInfoPopups(index) {
        debugMessage('showBurnerInfoPopups');
        $scope.showRTopInfoPopup = true;
        $timeout(function () {
            document.getElementById("burnerInfoPopupId").style.zIndex = 999;
            document.getElementById("burnerInfoDivId").style.zIndex = 999;
        }, 0);
        $scope.selectedRTopBurner = angular.isDefined(index) ? index : $scope.selectedRTopBurner;
        var value = $scope.cookTopBurnerArray[$scope.selectedRTopBurner].OperationState === 'Run' ? $scope.translation.WEBMOB_device_range_comm_on : $scope.translation.WEBMOB_device_off_off;
        $scope.selectedRTopDetail = $scope.translation.WEBMOB_device_cooktop_burner_state.replace(/#1#/, value.toLowerCase());
    }

    function versionTouchStart() {
        debugMessage("ABOUT command versionTouchStart ");
        if (!!!promiseAbout) {
            promiseAbout = $timeout(function () {
                if (!$scope.isStatic) {
                    $scope.checkResponse.push(COOKTOP_COMMANDS.showModuleVersion);
                    SHPService.sendSHPCommand(CONSTANTS.GET, "/" + $scope.peerId + "/devices/0/information");
                }
            }, 5000);
        }
    }

    function doValidationForBurnerTimer() {
        showDummyInbox();
        if ($scope.focuseRemoved) {
            $scope.focuseRemoved = false;
            //return;
        }
        var hr = Number(document.getElementById('brnrTimrHr').value);
        var min = Number(document.getElementById('brnrTimrMn').value);
        $scope.burnerTimer = (hr * 60) + min;
        if ($scope.burnerTimer > timerMaxValue) {
            $scope.burnerTimer = timerMaxValue;
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
        }
        if ($scope.burnerTimer < 0) {
            $scope.burnerTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (!($scope.burnerTimer)) {
            $scope.burnerTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (($scope.burnerTimer) % 1 !== 0 && ($scope.burnerTimer >= 00) && ($scope.burnerTimer <= timerMaxValue)) {
            $scope.burnerTimer = Math.ceil(Number($scope.burnerTimer) / 1) * 1;
        }
        burnerTimerDrag.roundSlider({value: $scope.burnerTimer, sliderType: "min-range", tab: 3});
        updateBurnerTimerValue($scope.burnerTimer);
    }

    function doValidationForTimer() {
        showDummyInbox();
        if ($scope.focuseRemoved) {
            $scope.focuseRemoved = false;
            //return;
        }
        if (!$scope.supportHrTimer) {
            $scope.kitchenTimer = Number(document.getElementById('kitchenTimer').value);
        } else {
            var hr = Number(document.getElementById('kchnTimrHr').value);
            var min = Number(document.getElementById('kchnTimrMn').value);
            $scope.kitchenTimer = (hr * 60) + min;
        }
        if ($scope.kitchenTimer > timerMaxValue) {
            $scope.kitchenTimer = timerMaxValue;
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
        }
        if ($scope.kitchenTimer < 0) {
            $scope.kitchenTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (!($scope.kitchenTimer)) {
            $scope.kitchenTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (($scope.kitchenTimer) % 1 !== 0 && ($scope.kitchenTimer >= 00) && ($scope.kitchenTimer <= timerMaxValue)) {
            $scope.kitchenTimer = Math.ceil(Number($scope.kitchenTimer) / 1) * 1;
        }
        kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", tab: 1});
        updateTimerValue($scope.kitchenTimer);
    }

    function doValidationForHoodTimer() {
        showDummyInbox();
        if ($scope.focuseRemoved) {
            $scope.focuseRemoved = false;
            //return;
        }
        if (!$scope.supportHrTimer) {
            $scope.hoodTimer = Number(document.getElementById('hoodTimer').value);
        } else {
            var hr = Number(document.getElementById('hoodTimrHr').value);
            var min = Number(document.getElementById('hoodTimrMn').value);
            $scope.hoodTimer = (hr * 60) + min;
        }
        if ($scope.hoodTimer > timerMaxValue) {
            $scope.hoodTimer = timerMaxValue;
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
        }
        if ($scope.hoodTimer < 0) {
            $scope.hoodTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (!($scope.hoodTimer)) {
            $scope.hoodTimer = 1;
            var text = $scope.translation.WEBMOB_device_range_alarm_minimum_temp;
            text = text.replace(/#1#/, '01');
            showToast(text);
        }

        if (($scope.hoodTimer) % 1 !== 0 && ($scope.hoodTimer >= 00) && ($scope.hoodTimer <= timerMaxValue)) {
            $scope.hoodTimer = Math.ceil(Number($scope.hoodTimer) / 1) * 1;
        }
        hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
        updateHoodTimerValue($scope.hoodTimer);
    }

    function versionTouchEnd() {
        debugMessage("ABOUT command versionTouchEnd ");
        if (!!promiseAbout) {
            $timeout.cancel(promiseAbout);
            promiseAbout = null;
        }
    }

    function goToSettings() {
        debugMessage('goToSettings');
        validateCurrentScreen('SettingPage');
    }

    function goToBurnerTimer() {
        if ($scope.DeviceModelName === 'NV9500M-/KO0') {
            return;// NV9500M-/KO0 model not support burnerTimer control just monitoring  
        }
        debugMessage('goToBurnerTimer');
        $scope.selectedBurnerTimer = $scope.burnerSelectedValue;
        goToBurnerTimerPage();
    }

    function goToBurnerTimerPage() {
        debugMessage('goToBurnerTimerPage');
        $scope.BurnerTimerState = '';
        $scope.burnerTimer = Math.floor(($scope.cookTopBurnerArray[$scope.selectedBurnerTimer].DownCountTimerCurrent) / 60);
        if ($scope.cookTopBurnerArray[$scope.selectedBurnerTimer].TimerState === 'Run') {
            $scope.BurnerTimerState = 'Run';
            $scope.startStopBurnerState = $scope.translation.WEBMOB_common_cooktop_pause;
        } else if ($scope.cookTopBurnerArray[$scope.selectedBurnerTimer].TimerState === 'Pause') {
            $scope.BurnerTimerState = 'Pause';
            $scope.startStopBurnerState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
        } else {
            $scope.BurnerTimerState = 'Ready';
            $scope.startStopBurnerState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
        }
        hideBurnerInfoPopup();
        burnerTimerDrag.roundSlider({value: $scope.burnerTimer, sliderType: "min-range", max: timerMaxValue, step: 1, tab: 3});
        updateBurnerTimerValue($scope.burnerTimer);
        validateCurrentScreen('BurnerTimerPage');
    }

    function showUsageHelpPage() {
        scroll_middle_area.scrollTop = 0;
        $scope.cTopPageFUG = true;
    }

    function closeUsageHelpPage() {
        if ($scope.cTopPageFUG) {
            $scope.cTopPageFUG = false;
        }
        if ($scope.hoodPageFUG) {
            $scope.hoodPageFUG = false;
        }
    }

    function gotoKitchenTimer() {
        debugMessage('gotoKitchenTimer');
        $scope.kitchenTimer = Number($scope.cookTopInfo.Mode.options[0].MainTimerCurrent);
        KitchenTimerPage();
    }

    function KitchenTimerPage() {
        debugMessage('KitchenTimerPage');
        //showDummyInbox();  // CQ MW0600025669 - In Kitchen timer screen, key pad closed after getdevice response and any notification. 
        kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", max: timerMaxValue, step: 1, tab: 1});
        $scope.updateTimerValue($scope.kitchenTimer);
        validateCurrentScreen('KitchenTimerPage');
    }

    function gotoHoodTimer() {
        debugMessage('gotoHoodTimer');
        if ($scope.hoodOff) {
            showToast($scope.translation.WEBMOB_device_hood_off);
            return;
        }
        //showDummyInbox(); // CQ MW0600025669 - In Kitchen timer screen, key pad closed after getdevice response and any notification. 
        //$scope.hoodTimer = $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent;
        hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", max: timerMaxValue, step: 1, tab: 2});
        $scope.updateHoodTimerValue($scope.hoodTimer);
        validateCurrentScreen('HoodTimerPage');
    }

    function addKitchenTimer(time) {
        if ($scope.cookTopInfo.Operation.power !== 'On') {
            showToast($scope.translation.WEBMOB_device_cooktop_off);
            return;
        }
        if ($scope.cookTopInfo.Operation.kidsLock === 'Run') {
            debugMessage("return Kids Lock is ON");
            showcustDialog(COOKTOP_ALERT_STATE.ALERT_CHILD_LOCK, $scope.translation.WEBMOB_common_device_cooktop, $scope.translation.WEBMOB_device_cooktop_child_lock_popup, $scope.translation.WEBMOB_common_ok, '');
            return;
        }
        var value = 0;
        /**
         * Updated as hood timer is behaving the same way - discussed with Mr. Choi
         */
        value = $scope.kitchenTimer; //Number($scope.cookTopInfo.Mode.options[0].MainTimerCurrent);
        value = value + Number(time);
        if (value > timerMaxValue) {
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
            return;
        }
        $scope.kitchenTimer = Number(value);
        updateTimerValue($scope.kitchenTimer);
        //sendKitchenTimer(value);
        //if ($scope.KitchenTimerState === 'Ready' || $scope.isStatic) {
        kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", tab: 1});
        //}
    }

    function addBurnerTimer(time) {
        //if ($scope.BurnerTimerState !== 'Run') {
        //    showToast('Burner is off');
        //    return;
        //}
        var value = 0;
        value = $scope.burnerTimer;
        value = value + Number(time);
        if (value > timerMaxValue) {
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
            return;
        }
        $scope.burnerTimer = Number(value);
        updateBurnerTimerValue($scope.burnerTimer);
        //if ($scope.BurnerTimerState === 'Ready' || $scope.isStatic) {
        burnerTimerDrag.roundSlider({value: $scope.burnerTimer, sliderType: "min-range", tab: 3});
        //}
    }

    function addHoodTimer(time) {
        if ($scope.hoodOff) {
            showToast($scope.translation.WEBMOB_device_hood_off);
            return;
        }
        var value = 0;
        value = $scope.hoodTimer;
        value = value + Number(time);
        if (value > timerMaxValue) {
            var text = $scope.translation.WEBMOB_device_range_alarm_maximum_temp;
            var max = $scope.supportHrTimer ? '12hr 59min' : 99;
            text = text.replace(/#1#/, max);
            showToast(text);
            return;
        }
        $scope.hoodTimer = Number(value);
        $scope.updateHoodTimerValue($scope.hoodTimer);
        //sendHoodTimer(value);
        //if ($scope.HoodTimerState === 'Ready' || $scope.isStatic) {
        hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
        //}
    }

    function startKitchenTimer() {
        if ($scope.supportHrTimer) {
            document.getElementById("kchnTimrHr").readOnly = true;
            document.getElementById("kchnTimrMn").readOnly = true;
        } else {
            document.getElementById("kitchenTimer").readOnly = true;
        }
        if ($scope.cookTopInfo.Operation.power !== 'On') {
            showToast($scope.translation.WEBMOB_device_cooktop_off);
            return;
        }
        if ($scope.cookTopInfo.Operation.kidsLock === 'Run') {
            debugMessage("return Kids Lock is ON");
            showcustDialog(COOKTOP_ALERT_STATE.ALERT_CHILD_LOCK, $scope.translation.WEBMOB_common_device_cooktop, $scope.translation.WEBMOB_device_cooktop_child_lock_popup, $scope.translation.WEBMOB_common_ok, '');
            return;
        }
        var value = 0;
        value = $scope.kitchenTimer;
        if (value > timerMaxValue) {
            value = timerMaxValue;
        } else if (value === 0) {
            value = '00';
        } else if (value > 0 && value < 10) {
            value = '0' + value;
        } else {
            value = '' + value;
        }
        if ($scope.startStopState === $scope.translation.WEBMOB_device_hood_stop_button) {
            value = '00';
        }
        if ($scope.KitchenTimerState === 'Ready' && value === '00') {
            showToast('Please set some Timer for cooking');//TODO STRING
        } else {
            sendKitchenTimer(value);
        }
    }

    function startHoodTimer() {
        if ($scope.supportHrTimer) {
            document.getElementById("hoodTimrHr").readOnly = true;
            document.getElementById("hoodTimrMn").readOnly = true;
        } else {
            document.getElementById("hoodTimer").readOnly = true;
        }
        if ($scope.hoodOff) {
            showToast($scope.translation.WEBMOB_device_hood_off);
            return;
        }
        var value = 0;
        value = $scope.hoodTimer;
        if (value > timerMaxValue) {
            value = timerMaxValue;
        } else if (value === 0) {
            value = '00';
        } else if (value > 0 && value < 10) {
            value = '0' + value;
        } else {
            value = '' + value;
        }
        if ($scope.startStopHoodState === $scope.translation.WEBMOB_device_hood_stop_button) {
            value = '00';
        }
        if ($scope.HoodTimerState === 'Ready' && value === '00') {
            showToast('Please set some Timer for cooking');//TODO STRING
        } else {
            sendHoodTimer(value);
        }
    }

    function startBurnerTimer() {
        if ($scope.supportHrTimer) {
            document.getElementById("brnrTimrHr").readOnly = true;
            document.getElementById("brnrTimrMn").readOnly = true;
        }
        if ($scope.cookTopBurnerArray[$scope.selectedBurnerTimer].OperationState !== 'Run'
                && $scope.cookTopBurnerArray[$scope.selectedBurnerTimer].OperationState !== 'Pause') {
            var text = $scope.translation.WEBMOB_device_cooktop_burner_state;
            text = text.replace(/#1#/, 'off');
            showToast(text);
            return;
        }
        if ($scope.cookTopInfo.Operation.power !== 'On') {
            showToast($scope.translation.WEBMOB_device_cooktop_off);
            return;
        }
        if ($scope.cookTopInfo.Operation.kidsLock === 'Run') {
            debugMessage("return Kids Lock is ON");
            showcustDialog(COOKTOP_ALERT_STATE.ALERT_CHILD_LOCK, $scope.translation.WEBMOB_common_device_cooktop, $scope.translation.WEBMOB_device_cooktop_child_lock_popup, $scope.translation.WEBMOB_common_ok, '');
            return;
        }
        var value = 0;
        value = $scope.burnerTimer;
        if (value > timerMaxValue) {
            value = timerMaxValue;
        } else if (value === 0) {
            value = '00';
        } else if (value > 0 && value < 10) {
            value = '0' + value;
        } else {
            value = '' + value;
        }
        if ($scope.startStopBurnerState === $scope.translation.WEBMOB_device_hood_stop_button) {
            value = '00';
        }
        if ($scope.BurnerTimerState === 'Ready' && value === '00') {
            showToast('Please set some Timer for cooking');//TODO STRING
        } else {
            sendBurnerTimer(value);
        }
    }

    function resetKitchenTimer() {
        debugMessage('resetKitchenTimer');
        showDummyInbox();
        if ($scope.KitchenTimerState === 'Run' || $scope.KitchenTimerState === 'Pause') {
            sendKitchenTimer(0);
        } else {
            $scope.kitchenTimer = 0;
            kitchenTimerDrag.roundSlider({value: $scope.kitchenTimer, sliderType: "min-range", tab: 1});
        }
    }

    function resetBurnerTimer() {
        debugMessage('resetKitchenTimer');
        showDummyInbox();
        if ($scope.BurnerTimerState === 'Run' || $scope.BurnerTimerState === 'Pause') {
            sendBurnerTimer(0);
        } else {
            $scope.burnerTimer = 0;
            $scope.cookTopBurnerArray[$scope.selectedBurnerTimer].DownCountTimerCurrent = 0;
            burnerTimerDrag.roundSlider({value: $scope.burnerTimer, sliderType: "min-range", tab: 3});
        }
    }

    function resetHoodTimer() {
        debugMessage('resetKitchenTimer');
        showDummyInbox();
        if ($scope.HoodTimerState !== 'Run') {
            $scope.hoodTimer = 0;
            hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
        }
    }

    function sendKitchenTimer(value) {
        var command;
        $scope.kitchenTimer = Number(value);
        if ($scope.supportHrTimer) {
            if ($scope.kitchenTimer > 779) {
                value = 779;
            }
            value = Number(value) * 60;
        }
        if (value === '00' || Number(value) < 1) {
            command = '{"Mode":{"options":["MainTimerSet_00","MainTimerState_Ready"]}}';
        } else if ($scope.startStopState === $scope.translation.WEBMOB_common_cooktop_pause) {
            command = '{"Mode":{"options":["MainTimerState_Pause"]}}';
        } else {
            command = '{"Mode":{"options":["' + 'MainTimerSet_' + value + '","MainTimerState_Run"]}}';
        }
        debugMessage("Setting command " + command);
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.kitchenTimer);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/0/mode");
        }
    }

    function sendBurnerTimer(value) {
        var command;
        $scope.burnerTimer = Number(value);
        if ($scope.burnerTimer > 779) {
            value = 779;
        }
        value = Number(value) * 60;
        if (value === '00' || Number(value) < 1) {
            command = '{"Mode":{"options":["' + 'DownCountTimerSet' + $scope.selectedBurnerTimer + '_00' + '","TimerState' + $scope.selectedBurnerTimer + '_Ready"]}}';
        } else if ($scope.startStopBurnerState === $scope.translation.WEBMOB_common_cooktop_pause) {
            command = '{"Mode":{"options":["TimerState' + $scope.selectedBurnerTimer + '_Pause"]}}';
        } else {
            command = '{"Mode":{"options":["' + 'DownCountTimerSet' + $scope.selectedBurnerTimer + '_' + value + '","TimerState' + $scope.selectedBurnerTimer + '_Run"]}}';
        }
        debugMessage("Setting command " + command);
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.BurnerTimer);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/0/mode");
        }
    }

    function sendHoodTimer(value) {
        var command;
        $scope.hoodTimer = Number(value);
        if (value === '00' || Number(value) < 1) {
            command = '{"Mode":{"options":["ShutOffTimerSet_00","ShutOffTimerState_Ready"]}}';
        } else {
            command = '{"Mode":{"options":["' + 'ShutOffTimerSet_' + value + '","ShutOffTimerState_Run"]}}';
        }
        debugMessage("Setting command " + command);
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.hoodTimer);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/1/mode");
        }
    }

    function hoodPowerButton() {
        var command;
        if (!$scope.hoodOff) {
            command = '{"Operation": {"power": "Off"}}';
        } else {
            command = '{"Operation": {"power": "On"}}';
        }
        //$scope.hoodOff = !$scope.hoodOff;
        debugMessage(command + "/" + $scope.peerId + "/devices/1/operation");
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.hoodPower);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/1/operation");
        }
    }

    function setLightStatus() {
        if ($scope.hoodLight) {
            $scope.hoodLightPosition = $scope.hoodOff ? 'off_light_on' : 'on_light_on';
        } else {
            $scope.hoodLightPosition = 'off';
        }
    }

    function setFanStatus(value) {
        if (value === 1) {
            $scope.fanStatus = 'low';
            $scope.fanText = "WEBMOB_device_hood_low";
        } else if (value === 2) {
            $scope.fanStatus = 'med';
            $scope.fanText = "WEBMOB_device_hood_medium";
        } else if (value === 3) {
            $scope.fanStatus = 'high';
            $scope.fanText = "WEBMOB_device_hood_high";
        } else if (value === 4) {
            $scope.fanStatus = 'boost';
            $scope.fanText = "WEBMOB_device_hood_boost";
        } else if (value === 5) {
            $scope.fanStatus = 'auto';
            $scope.fanText = "WEBMOB_device_hood_auto";
        }
    }

    function hoodFanButton(value) {
        if ($scope.selectedFanValue === value) {
            return;
        }
        hideFanOption();
        var command;
        setFanStatus(value);
        $scope.selectedFanValue = value;
        command = '{"Mode":{"options":["FanSpeed_' + value + '"]}}';
        debugMessage(command + "/" + $scope.peerId + "/devices/1/mode");
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.hoodFan);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/1/mode");
        }
    }

    function hoodLightButton() {
        var command, value = 'Off';
        $scope.hoodLight = !$scope.hoodLight;
        setLightStatus();
        value = $scope.hoodLight ? 'On' : 'Off';
        command = '{"Mode":{"options":["Lamp_' + value + '"]}}';
        debugMessage(command + "/" + $scope.peerId + "/devices/1/mode");
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.hoodLight);
            SHPService.sendSHPCommand(CONSTANTS.PUT, command, "/" + $scope.peerId + "/devices/1/mode");
        }

    }

    function toggleAutoConnectivity() {
        debugMessage('toggleAutoConnectivity');
        $scope.autoConnectivity = !$scope.autoConnectivity;
    }

    function gotoSmartControl() {
        if ($scope.detailPageFUG) {
            return;
        }
        debugMessage('gotoSmartControl');
        $scope.smartControl = $scope.remoteControlEnabled ? 'ON' : 'OFF';
        document.getElementById("showsmartControlfullScreenPopupId").style.zIndex = 999;
        document.getElementById("smartControlPopupDivId").style.zIndex = 999;
        $scope.samrtControlPopup = true;
    }

    function hideSmartControlOption() {
        debugMessage('hideSmartControlOption');
        $scope.samrtControlPopup = false;
    }

    function goToAbout() {
        debugMessage('goToAbout');
        validateCurrentScreen('AboutPage');
    }

    function gotoRecipePage() {
        return;
        debugMessage('gotoRecipePage');
        hideBurnerInfoPopup();
        validateCurrentScreen('RecipeListPage');
    }

    function swipeCookingLeft(id) {
        if ($scope.RecipeIngredientSteps >= id && id > $scope.recipeStep) {
            $scope.recipeStep = id;
        }
    }

    function swipeCookingRight(id) {
        if (id < $scope.recipeStep) {
            $scope.recipeStep = id;
        }
    }

    function detailRecipe() {
        return;
        debugMessage('detailRecipe');
        hideBurnerInfoPopup();
        selectRecipe($scope.SelectedRecipe);
    }

    function selectRecipe(recipe) {
        debugMessage('select Recipe id ' + recipe.id);
        $scope.recipeIngredientScreen = true;
        $scope.RecipeIngredientTilte = $scope.translation[recipe.title];
        $scope.RecipeIngredientImage = recipe.image;
        $scope.RecipeIngredient = recipe.ingredient;
        $scope.RecipeIngredientTime = recipe.time;
        $scope.RecipeIngredientLevel = recipe.level;
        $scope.RecipeIngredientSteps = recipe.steps;
        $scope.RecipeIngredientServingSize = recipe.serving;
        $scope.RecipeIngredientStep1Title = recipe.step1 + 'title';
        $scope.RecipeIngredientStep1Desc = recipe.step1 + 'description';
        if ($scope.RecipeIngredientSteps > 1) {
            $scope.RecipeIngredientStep2Title = recipe.step2 + 'title';
            $scope.RecipeIngredientStep2Desc = recipe.step2 + 'description';
        }
        if ($scope.RecipeIngredientSteps > 2) {
            $scope.RecipeIngredientStep3Title = recipe.step3 + 'title';
            $scope.RecipeIngredientStep3Desc = recipe.step3 + 'description';
        }
        if ($scope.RecipeIngredientSteps > 3) {
            $scope.RecipeIngredientStep4Title = recipe.step4 + 'title';
            $scope.RecipeIngredientStep4Desc = recipe.step4 + 'description';
        }
        $scope.recipeStep = 0;
        debugMessage('select Recicwfdwfdwpe id ' + $scope.RecipeIngredientStep3Title);
        validateCurrentScreen('RecipeIngredientPage');
    }

    function closeApp() {
        debugMessage('closeApp');
        nativeInterface.runOnNative("closeWebApp", "");
    }

    function dismissLoadingBar(value) {
        debugMessage("dismissLoadingBar " + $scope.checkResponse + " value " + value);
        if ($scope.appAtForeground) {
            return;
        }

        if ($scope.checkResponse.indexOf(value) !== -1) {
            $scope.checkResponse.splice($scope.checkResponse.indexOf(value), 1);
            dismissLoadingBar(value);
            if ($scope.checkResponse.length === 0) {
                $scope.loadingBar = false;
                hideInputBoxFocus();
            }
        }
    }

    function initializeScreen() {
        debugMessage('initializeScreen  and all model check');
        if ($scope.cookTopInfo === undefined) {
            return;
        }
        $scope.DeviceModelName = $scope.cookTopInfo.Mode.options[0].DeviceType;
        debugMessage('DeviceModelName ' + $scope.DeviceModelName);
        $scope.leftFlex = $scope.DeviceModelName === 'NV9300K-/AA3' || $scope.DeviceModelName === 'NV9300K-/AA4'
                || $scope.DeviceModelName === 'NV9500M-/AA0' || $scope.DeviceModelName === 'NV9500M-/AA1' || $scope.DeviceModelName === 'NV9500M-/KO0';
        $scope.rightFlex = $scope.DeviceModelName === 'NV9500M-/AA0';
        $scope.supportHrTimer = $scope.DeviceModelName === 'NV9500M-/AA0' || $scope.DeviceModelName === 'NV9500M-/AA1' || $scope.DeviceModelName === 'NV9500M-/KO0';
        timerMaxValue = $scope.supportHrTimer ? 780 : 99;
        $scope.cookTopBaseBurner = 'COOKTOP/assets/img/burner/ct_ect';
        $scope.showBrige = false;
        $scope.flexCss = '';
        $scope.showFUGBurner = false;
        $scope.rTopType = '';
        /*Note: CookTop type based on Model ID(DeviceType)
         case 0:
         NE9000K
         case 1:
         case default:
         NV9300K-/AA0 >> NZ9300K(Radiant-P, 30/36)(No Pan)
         NV9300K-/AA1 >> NZ9300K(Radiant-P+, 30)
         case 2:
         NV9300K-/AA2 >> NZ9300K(Radiant-P+, 36) 
         case 3:
         NV9300K-/AA3 >> NZ9500K(Induction-P+, 30)
         NV9500M-/AA1 >> NZ9500M(Induction-Dacor, 30")
         NV9500M-/KO0 >> NZ9500M(Induction-Dacor Korean Model, 30")        
         case 4:
         NV9300K-/AA4 >> NZ9500K(Induction-P+, 36)
         case 5:
         NA9300K-/AA0 >> NA9300K(Gas P) 
         NA9300K-/AA1 >> NA9300K(Gas P+)
         case 6:
         NV9500M-/AA0 >> NZ9500M(Induction cooktop-Dacor, 36)
         case 7:
         NA9300M-/AA0 >> NA9300M(Gas cooktop-Dacor, 36)
         case 8:
         NA9300M-/AA1 >> NA9300M(Gas cooktop-Dacor, 30)
         case 9 :
         NA9900M-/AA0 >> NA9300M(Gas rangeTop-Dacor, 48)
         case 10:
         NA9900M-/AA1 >> NA9300M(Gas rangeTop-Dacor, 36)
         */
        switch ($scope.DeviceModelName) {
            case "NE9000K":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ne9000k';
                $scope.cookTopBaseBurner = 'COOKTOP/assets/img/burner/ct_ne9000k';
                $scope.cookTopType = '0';
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_01';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_01';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_03';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_01';//not using
                break;
            case "NV9300K-/AA1":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '1';
                $scope.showBrige = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                $scope.cookTopBurnerArray[3].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[5].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[3].SubBurnerSupport = true;
                $scope.cookTopBurnerArray[5].SubBurnerSupport = true;
                break;
            case "NV9300K-/AA2":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '2';
                $scope.showBrige = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_04';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                $scope.cookTopBurnerArray[3].subBurnerId = '_02';//01-02-03
                $scope.cookTopBurnerArray[5].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[3].SubBurnerSupport = true;
                $scope.cookTopBurnerArray[5].SubBurnerSupport = true;
                break;
            case "NV9300K-/AA3":
            case "NV9500M-/AA1":
            case "NV9500M-/KO0":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '3';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = '';
                $scope.cookTopBurnerArray[1].BurnerImageID = '';
                $scope.cookTopBurnerArray[2].BurnerImageID = '';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_07';
                $scope.cookTopBurnerArray[4].BurnerImageID = '';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_08';
                $scope.cookTopBurnerArray[0].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[0].SubBurnerSupport = true;
                break;
            case "NV9300K-/AA4":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '4';
                $scope.cookTopBurnerArray[0].BurnerImageID = '';
                $scope.cookTopBurnerArray[1].BurnerImageID = '';
                $scope.cookTopBurnerArray[2].BurnerImageID = '';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_07';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_08';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_09';//TODO
                $scope.cookTopBurnerArray[0].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[0].SubBurnerSupport = true;
                break;
            case "NA9300K-/AA0":
            case "NA9300K-/AA1":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_gct';
                $scope.cookTopBaseBurner = 'COOKTOP/assets/img/burner/ct_gct';
                $scope.cookTopType = '5';
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_04';
                break;
            case "NV9500M-/AA0":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '6';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = '';
                $scope.cookTopBurnerArray[1].BurnerImageID = '';
                $scope.cookTopBurnerArray[2].BurnerImageID = '';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_07';
                $scope.cookTopBurnerArray[4].BurnerImageID = '';
                $scope.cookTopBurnerArray[5].BurnerImageID = '';
                $scope.cookTopBurnerArray[0].subBurnerId = '_02';//01-02
                $scope.cookTopBurnerArray[0].SubBurnerSupport = true;
                break;
            case "NA9300M-/AA0":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_gct_36';
                $scope.cookTopBaseBurner = 'COOKTOP/assets/img/burner/ct_gct';
                $scope.cookTopType = '7';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_03';
                break;
            case "NA9300M-/AA1":
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_gct_30';
                $scope.cookTopBaseBurner = 'COOKTOP/assets/img/burner/ct_gct';
                $scope.FugBurnerDetail = $scope.translation.WEBMOB_device_cooktop_status1.replace(/#1#/, 2);
                $scope.cookTopType = '8';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';//not using
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_03';
                break;
            case "NA9900M-/AA0":
                $scope.cookTopBaseImage = '';//not using
                $scope.cookTopBaseBurner = '';//not using
                $scope.FugBurnerDetail = $scope.translation.WEBMOB_device_cooktop_status1.replace(/#1#/, 3);
                $scope.cookTopType = '';//not using
                $scope.rTopType = '48';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[1].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[2].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[3].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[4].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[5].BurnerImageID = '';//not using
                break;
            case "NA9900M-/AA1":
                $scope.cookTopBaseImage = '';//not using
                $scope.cookTopBaseBurner = '';//not using
                $scope.FugBurnerDetail = $scope.translation.WEBMOB_device_cooktop_status1.replace(/#1#/, 3);
                $scope.cookTopType = '';//not using
                $scope.rTopType = '36';
                $scope.showFUGBurner = true;
                $scope.cookTopBurnerArray[0].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[1].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[2].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[3].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[4].BurnerImageID = '';//not using
                $scope.cookTopBurnerArray[5].BurnerImageID = '';//not using
                break;
            case "NV9300K-/AA0":
            default:
                $scope.cookTopBaseImage = 'COOKTOP/assets/img/burner/ct_ect';
                $scope.cookTopType = '1';
                $scope.cookTopBurnerArray[0].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[1].BurnerImageID = 'burner_circle_01';
                $scope.cookTopBurnerArray[3].BurnerImageID = 'burner_circle_02';
                $scope.cookTopBurnerArray[4].BurnerImageID = 'burner_circle_03';
                $scope.cookTopBurnerArray[5].BurnerImageID = 'burner_circle_04';
                $scope.cookTopBurnerArray[2].BurnerImageID = 'burner_circle_01';//not using
                break;
        }
    }

    function showCurrentScreen() {
        debugMessage("showCurrentScreen called");
        if ($scope.cookTopInfo === undefined || $scope.HoodInfo === undefined) {
            debugMessage("cookTopInfo is undefined");
            return;
        }

        if (!parseNotificationFlag && !$scope.isStatic) {
            debugMessage("waiting for getDevice response");
            return;
        }

        if (getAlarmStatusCooktop()) {
            return;
        }

        if (changeSmartCarePage && ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_NO_ERROR_PAGE || $scope.currentScreen === COOKTOP_SCREENS.COOKTOP_SMART_CARE_PAGE)) {
            debugMessage('return due to Smart Care');
            return;
        }
        //loadingValues();

        $scope.showHood = $scope.HoodInfo.Mode.options[0].Hood === 'connected' && $scope.HoodInfo.Mode.options[0].Bluetooth === 'On';
        if (!$scope.showHood) {
            $scope.cTopTabSelected = true;
            if ($scope.currentScreen === 4) {
                doNotChangeScreen = false;
                validateCurrentScreen('BurnerHomePage');
            }
        }

        if ($scope.hoodOff) {
            $scope.HoodTimerState = 'Ready';
            $scope.hoodTimer = 0;
            $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent = 0;
            hoodTimerDrag.roundSlider({value: $scope.hoodTimer, sliderType: "min-range", tab: 2});
            if ($scope.currentScreen === 4) {
                doNotChangeScreen = false;
                validateCurrentScreen('BurnerHomePage');
            }
        }

        if (!$scope.cTopTabSelected) {
            showHoodScreen();
            return;
        }

        if ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_KITCHEN_TIMER_PAGE) {
            debugMessage('return due to COOKTOP_KITCHEN_TIMER_PAGE screen');
            KitchenTimerPage();
            return;
        }

        if ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_HOOD_TIMER_PAGE) {
            debugMessage('return due to COOKTOP_HOOD_TIMER_PAGE screen');
            gotoHoodTimer();
            return;
        }

        if ($scope.currentScreen === COOKTOP_SCREENS.COOKTOP_BURNER_TIMER_PAGE) {
            debugMessage('return due to COOKTOP_BURNER_TIMER_PAGE screen');
            updateCookTopBurnerValues();
            goToBurnerTimerPage();
            return;
        }

        if (doNotChangeScreen) {
            debugMessage('return due to doNotChangeScreen');
            return;
        }
        updateCookTopBurnerValues();

        justFirstTime = false;
        showScreen();
        debugMessage("Screen Loading finish and checkResponse values " + $scope.checkResponse);
    }

    function showScreen() {
        debugMessage("showScreen called");
        $timeout(function () {
            validateCurrentScreen('BurnerHomePage');
        }, 0);
    }

    function showHoodScreen() {
        debugMessage("showHoodScreen");
        $scope.hoodOff = $scope.HoodInfo.Operation.power === 'Off' ? true : false;
        $scope.hoodLight = $scope.HoodInfo.Mode.options[0].Lamp === 'On' ? true : false;
        $scope.selectedFanValue = $scope.HoodInfo.Operation.power === 'Off' ? 1 : $scope.selectedFanValue;
        $scope.hoodTimerLeftTime = Number($scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent) > 1 ? $scope.translation.WEBMOB_device_cooktop_timer_left2.replace(/#1#/, $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent) : $scope.translation.WEBMOB_device_cooktop_timer_left.replace(/#1#/, $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent);
        setLightStatus();
        setFanStatus($scope.selectedFanValue);
    }

    function loadingValues() {
        if ($scope.checkResponse.indexOf(COOKTOP_COMMANDS.kitchenTimer) !== -1) {
            $timeout(function () {
                dismissKitchenTimerCommand();
            }, 20000);
        }
    }

    function dismissKitchenTimerCommand() {
        if ($scope.checkResponse.indexOf(COOKTOP_COMMANDS.kitchenTimer) !== -1) {
            dismissLoadingBar(COOKTOP_COMMANDS.kitchenTimer);
        }
    }

    function updateCookTopBurnerValues() {
        debugMessage('updateCookTopValues');
        updateZeroBurner();
        updateFirstBurner();
        updateSecondBurner();
        updateThirdBurner();
        updateFourthBurner();
        updateFifthBurner();
        $scope.runningBurner = [];
        $scope.cookTopBurnerPause = checkPauseState(); //check for cooktop pause state

        for (var i = 0; i < $scope.cookTopBurnerArray.length; i++) {
            if ($scope.cookTopBurnerArray[i].OperationState === 'Run' || $scope.cookTopBurnerArray[i].OperationState === 'Pause') {
                $scope.runningBurner.push($scope.cookTopBurnerArray[i].id);
            }
        }
        var text = $scope.translation.WEBMOB_device_cooktop_status1;
        text = text.replace(/#1#/, $scope.runningBurner.length);
        $scope.runningBurnerText = text;
        if ($scope.showRTopInfoPopup) {
            showRTopInfoPopups();
        }
        updateBrige();
        if ($scope.flexCoilSelectedValue === -1 && !$scope.cookTopBurnerArray[0].ImageSelected &&
                !$scope.cookTopBurnerArray[1].ImageSelected &&
                !$scope.cookTopBurnerArray[2].ImageSelected &&
                !$scope.cookTopBurnerArray[3].ImageSelected &&
                !$scope.cookTopBurnerArray[4].ImageSelected &&
                !$scope.cookTopBurnerArray[5].ImageSelected &&
                (document.getElementById("burnerDetail") !== undefined && document.getElementById("burnerDetail") !== null)) {
            document.getElementById("burnerDetail").style.visibility = "hidden";
        }
    }

    function updateZeroBurner() {
        if (!$scope.leftFlex) {
            //$scope.cookTopBurnerArray[0].ImageOff = true;//$scope.cookTopBurnerArray[0].OperationState === 'Ready';
            $scope.cookTopBurnerArray[0].ImageOn = $scope.cookTopBurnerArray[0].OperationState === 'Run' || $scope.cookTopBurnerArray[0].OperationState === 'Pause';
            $scope.cookTopBurnerArray[0].UpperText = getUpperTextStatus(0);
            $scope.cookTopBurnerArray[0].LowerText = getLowerTextStatus(0);
            $scope.cookTopBurnerArray[0].CenterText = getCenerTextStatus(0);
        } else {
            // ch0 upper
            $scope.flexCoilStatus[0].UpperText = getFlexUpperTextStatus(0, 0);
            $scope.flexCoilStatus[0].LowerText = getLowerTextStatus(0, 0);
            $scope.flexCoilStatus[0].CenterText = getFlexCenerTextStatus(0, 0);
            // ch0 lower
            $scope.flexCoilStatus[1].UpperText = getFlexUpperTextStatus(0, 1);
            $scope.flexCoilStatus[1].LowerText = getLowerTextStatus(0, 1);
            $scope.flexCoilStatus[1].CenterText = getFlexCenerTextStatus(0, 1);
        }
    }

    function updateFirstBurner() {
        if (!$scope.leftFlex) {
            //$scope.cookTopBurnerArray[1].ImageOff = true;//$scope.cookTopBurnerArray[1].OperationState === 'Ready';
            $scope.cookTopBurnerArray[1].ImageOn = $scope.cookTopBurnerArray[1].OperationState === 'Run' || $scope.cookTopBurnerArray[1].OperationState === 'Pause';
            $scope.cookTopBurnerArray[1].UpperText = getUpperTextStatus(1);
            $scope.cookTopBurnerArray[1].LowerText = getLowerTextStatus(1);
            $scope.cookTopBurnerArray[1].CenterText = getCenerTextStatus(1);
        } else {
            // ch1 upper
            $scope.flexCoilStatus[2].UpperText = getFlexUpperTextStatus(1, 2);
            $scope.flexCoilStatus[2].LowerText = getLowerTextStatus(1, 2);
            $scope.flexCoilStatus[2].CenterText = getFlexCenerTextStatus(1, 2);
            // ch1 lower
            $scope.flexCoilStatus[3].UpperText = getFlexUpperTextStatus(1, 3);
            $scope.flexCoilStatus[3].LowerText = getLowerTextStatus(1, 3);
            $scope.flexCoilStatus[3].CenterText = getFlexCenerTextStatus(1, 3);
        }
    }

    function updateSecondBurner() {
        //scope.cookTopBurnerArray[2].ImageOff = true;//$scope.cookTopBurnerArray[2].OperationState === 'Ready';
        $scope.cookTopBurnerArray[2].ImageOn = $scope.cookTopBurnerArray[2].OperationState === 'Run' || $scope.cookTopBurnerArray[2].OperationState === 'Pause';
        $scope.cookTopBurnerArray[2].UpperText = getUpperTextStatus(2);
        $scope.cookTopBurnerArray[2].LowerText = getLowerTextStatus(2);
        $scope.cookTopBurnerArray[2].CenterText = getCenerTextStatus(2);
    }

    function updateThirdBurner() {
        //$scope.cookTopBurnerArray[3].ImageOff = true;//$scope.cookTopBurnerArray[3].OperationState === 'Ready';
        $scope.cookTopBurnerArray[3].ImageOn = $scope.cookTopBurnerArray[3].OperationState === 'Run' || $scope.cookTopBurnerArray[3].OperationState === 'Pause';
        $scope.cookTopBurnerArray[3].UpperText = getUpperTextStatus(3);
        $scope.cookTopBurnerArray[3].LowerText = getLowerTextStatus(3);
        $scope.cookTopBurnerArray[3].CenterText = getCenerTextStatus(3);
        if ($scope.cookTopBurnerArray[3].OperationState === 'Run' && $scope.cookTopBurnerArray[3].SubBurnerSupport) {
            if ($scope.cookTopBurnerArray[3].PanSize === 'Single') {
                $scope.cookTopBurnerArray[3].subBurnerId = '_01';
            } else if ($scope.cookTopBurnerArray[3].PanSize === 'Dual') {
                $scope.cookTopBurnerArray[3].subBurnerId = '_02';
            } else if ($scope.cookTopBurnerArray[3].PanSize === 'Triple') {
                $scope.cookTopBurnerArray[3].subBurnerId = '_03';
            }
        } else {
            $scope.cookTopBurnerArray[3].subBurnerId = '';
        }
        if ($scope.cookTopBurnerArray[3].subBurnerId === '' && $scope.cookTopBurnerArray[3].SubBurnerSupport) {
            $scope.cookTopBurnerArray[3].subBurnerId = '_02';
        }
    }

    function updateFourthBurner() {
        if (!$scope.rightFlex) {
            //$scope.cookTopBurnerArray[4].ImageOff = true;//$scope.cookTopBurnerArray[4].OperationState === 'Ready';
            $scope.cookTopBurnerArray[4].ImageOn = $scope.cookTopBurnerArray[4].OperationState === 'Run' || $scope.cookTopBurnerArray[4].OperationState === 'Pause';
            $scope.cookTopBurnerArray[4].UpperText = getUpperTextStatus(4);
            $scope.cookTopBurnerArray[4].LowerText = getLowerTextStatus(4);
            $scope.cookTopBurnerArray[4].CenterText = getCenerTextStatus(4);
            if ($scope.cookTopBurnerArray[4].OperationState === 'Run' && $scope.cookTopBurnerArray[4].SubBurnerSupport) {
                if ($scope.cookTopBurnerArray[4].PanSize === 'Single') {
                    $scope.cookTopBurnerArray[4].subBurnerId = '_01';
                } else if ($scope.cookTopBurnerArray[5].PanSize === 'Dual') {
                    $scope.cookTopBurnerArray[4].subBurnerId = '_02';
                } else if ($scope.cookTopBurnerArray[5].PanSize === 'Triple') {
                    $scope.cookTopBurnerArray[4].subBurnerId = '_03';
                }
            } else {
                $scope.cookTopBurnerArray[4].subBurnerId = '';
            }
            if ($scope.cookTopBurnerArray[4].subBurnerId === '' && $scope.cookTopBurnerArray[4].SubBurnerSupport) {
                $scope.cookTopBurnerArray[4].subBurnerId = '_02';
            }
        } else {
            // ch4 upper
            $scope.flexCoilStatus[4].UpperText = getFlexUpperTextStatus(4, 4);
            $scope.flexCoilStatus[4].LowerText = getLowerTextStatus(4, 4);
            $scope.flexCoilStatus[4].CenterText = getFlexCenerTextStatus(4, 4);
            // ch4 lower
            $scope.flexCoilStatus[5].UpperText = getFlexUpperTextStatus(4, 5);
            $scope.flexCoilStatus[5].LowerText = getLowerTextStatus(4, 5);
            $scope.flexCoilStatus[5].CenterText = getFlexCenerTextStatus(4, 5);
        }
    }

    function updateFifthBurner() {
        if (!$scope.rightFlex) {
            //$scope.cookTopBurnerArray[5].ImageOff = true;//$scope.cookTopBurnerArray[5].OperationState === 'Ready';
            $scope.cookTopBurnerArray[5].ImageOn = $scope.cookTopBurnerArray[5].OperationState === 'Run' || $scope.cookTopBurnerArray[5].OperationState === 'Pause';
            $scope.cookTopBurnerArray[5].UpperText = getUpperTextStatus(5);
            $scope.cookTopBurnerArray[5].LowerText = getLowerTextStatus(5);
            $scope.cookTopBurnerArray[5].CenterText = getCenerTextStatus(5);
            if ($scope.cookTopBurnerArray[5].OperationState === 'Run' && $scope.cookTopBurnerArray[5].SubBurnerSupport) {
                if ($scope.cookTopBurnerArray[5].PanSize === 'Single') {
                    $scope.cookTopBurnerArray[5].subBurnerId = '_01';
                } else if ($scope.cookTopBurnerArray[5].PanSize === 'Dual') {
                    $scope.cookTopBurnerArray[5].subBurnerId = '_02';
                } else if ($scope.cookTopBurnerArray[5].PanSize === 'Triple') {
                    $scope.cookTopBurnerArray[5].subBurnerId = '_03';
                }
            } else {
                $scope.cookTopBurnerArray[5].subBurnerId = '';
            }
            if ($scope.cookTopBurnerArray[5].subBurnerId === '' && $scope.cookTopBurnerArray[5].SubBurnerSupport) {
                $scope.cookTopBurnerArray[5].subBurnerId = '_02';
            }
        } else {
            // ch5 upper
            $scope.flexCoilStatus[6].UpperText = getFlexUpperTextStatus(5, 6);
            $scope.flexCoilStatus[6].LowerText = getLowerTextStatus(5, 6);
            $scope.flexCoilStatus[6].CenterText = getFlexCenerTextStatus(5, 6);
            // ch5 lower
            $scope.flexCoilStatus[7].UpperText = getFlexUpperTextStatus(5, 7);
            $scope.flexCoilStatus[7].LowerText = getLowerTextStatus(5, 7);
            $scope.flexCoilStatus[7].CenterText = getFlexCenerTextStatus(5, 7);
        }
    }

    function getCurrentStatus(id) {
        var value = 'off';
        if (id !== undefined) {
            if ($scope.cookTopBurnerArray[id].OperationState === 'Ready') {
                value = 'off';
            }
            if ($scope.cookTopBurnerArray[id].OperationState === 'Run' || $scope.cookTopBurnerArray[id].OperationState === 'Pause') {
                value = 'on';
            }
            if ($scope.cookTopBurnerArray[id].Selected) {
                value = 'select';
            }
        }
        //debugMessage('current value of ' + id + ' burner is : ' + value + " && " + $scope.runningBurner);
        return value;
    }

    function getCenerTextStatus(id) {
        var value = '';
        if (id !== undefined) {
            if ($scope.cookTopBurnerArray[id].OperationState === 'Ready') {
                value = 'OFF';
            }
            if (($scope.cookTopBurnerArray[id].OperationState === 'Run' || $scope.cookTopBurnerArray[id].OperationState === 'Pause') && ($scope.cookTopBurnerArray[id].UpperText === '' || $scope.cookTopBurnerArray[id].LowerText === '')) {
                value = 'ON';
                $scope.cookTopBurnerArray[id].UpperText = '';
                $scope.cookTopBurnerArray[id].LowerText = '';
            }
        }
        //ReSet Upper/Lower Text
        if ($scope.cookTopBurnerArray[id].UpperText === 'ON') {
            if ($scope.cookTopBurnerArray[id].PowerLevelShow && !$scope.cookTopBurnerArray[id].BurnerTimeShow) {
                $scope.cookTopBurnerArray[id].LowerText = $scope.cookTopBurnerArray[id].PowerLevelValue;
            }
            if (!$scope.cookTopBurnerArray[id].PowerLevelShow && $scope.cookTopBurnerArray[id].BurnerTimeShow) {
                $scope.cookTopBurnerArray[id].LowerText = $scope.cookTopBurnerArray[id].BurnerTime;
            }
            if ($scope.cookTopBurnerArray[id].PowerLevelShow && $scope.cookTopBurnerArray[id].BurnerTimeShow) {
                $scope.cookTopBurnerArray[id].UpperText = $scope.cookTopBurnerArray[id].PowerLevelValue;
                $scope.cookTopBurnerArray[id].LowerText = $scope.cookTopBurnerArray[id].BurnerTime;
            }
        }
        if (value !== '' && $scope.cookTopBurnerArray[id].LowerText !== '') {
            $scope.cookTopBurnerArray[id].UpperText = value;
            value = '';
        }
        $scope.cookTopBurnerArray[id].CenterText = value;
        //Selected
        if ($scope.cookTopBurnerArray[id].ImageSelected) {
            if ($scope.cookTopBurnerArray[id].OperationState === 'Pause') {
                var text = $scope.translation.WEBMOB_device_cooktop_detailed_level_info;
                text = text.replace(/#1#/, 2);
                $scope.selectedBurnerDetail = text;
            } else {
                setSelectedBurnerStatus(id);
            }
        }
        //debugMessage('current value of ' + id + ' Center text is : ' + value);
        return value;
    }

    function getFlexCenerTextStatus(id, flexid) {
        var value = '';
        if (id !== undefined) {
            //OnOff 
            if ($scope.flexCoilStatus[flexid].UpperText === '' || $scope.flexCoilStatus[flexid].LowerText === '') {
                if ($scope.flexCoilStatus[flexid].FlexOn) {
                    value = 'ON';
                } else {
                    value = 'OFF';
                }
                $scope.flexCoilStatus[flexid].UpperText = '';
                $scope.flexCoilStatus[flexid].LowerText = '';
            }
            //ReSet Upper/Lower Text
            if ($scope.flexCoilStatus[flexid].UpperText === 'ON') {
                if ($scope.cookTopBurnerArray[id].PowerLevelShow && !$scope.cookTopBurnerArray[id].BurnerTimeShow) {
                    $scope.flexCoilStatus[flexid].LowerText = $scope.cookTopBurnerArray[id].PowerLevelValue;
                }
                if (!$scope.cookTopBurnerArray[id].PowerLevelShow && $scope.cookTopBurnerArray[id].BurnerTimeShow) {
                    $scope.flexCoilStatus[flexid].LowerText = $scope.cookTopBurnerArray[id].BurnerTime;
                }
                if ($scope.cookTopBurnerArray[id].PowerLevelShow && $scope.cookTopBurnerArray[id].BurnerTimeShow) {
                    $scope.flexCoilStatus[flexid].UpperText = $scope.cookTopBurnerArray[id].PowerLevelValue;
                    $scope.flexCoilStatus[flexid].LowerText = $scope.cookTopBurnerArray[id].BurnerTime;
                }
            }
            if (value !== '' && $scope.flexCoilStatus[flexid].LowerText !== '') {
                $scope.flexCoilStatus[flexid].UpperText = value;
                value = '';
            }
            //ReSet Upper/Lower Hotness
            $scope.cookTopBurnerArray[id].Hotness = false;
            if ($scope.cookTopBurnerArray[id].OperationState === 'Ready' || !$scope.flexCoilStatus[flexid].FlexOn) {
                if (readChildValue(flexid)
                        && ($scope.cookTopBurnerArray[id].HotSurface_1 === 'SmallHot' || $scope.cookTopBurnerArray[id].HotSurface_1 === 'Hot')
                        || ($scope.cookTopBurnerArray[id].HotSurface === 'SmallHot' || $scope.cookTopBurnerArray[id].HotSurface === 'Hot')) {
                    var status = readChildValue(flexid) ? $scope.cookTopBurnerArray[id].HotSurface_1 : $scope.cookTopBurnerArray[id].HotSurface;
                    if (status === 'SmallHot') {
                        value = '';
                        $scope.cookTopBurnerArray[id].Hotness = true;
                        $scope.flexCoilStatus[flexid].UpperText = 'OFF';
                        $scope.flexCoilStatus[flexid].LowerText = $scope.translation.WEBMOB_device_cooktop_hot;//'Hot';
                    } else if (status === 'Hot') {
                        value = '';
                        $scope.cookTopBurnerArray[id].Hotness = true;
                        $scope.flexCoilStatus[flexid].UpperText = 'OFF';
                        $scope.flexCoilStatus[flexid].LowerText = $scope.translation.WEBMOB_device_cooktop_veryhot;//'Very Hot'
                    } else {
                        ;//NULL
                    }
                }
            }
            $scope.flexCoilStatus[flexid].CenterText = value;
            //Selected 
            if ($scope.cookTopBurnerArray[id].ImageSelected) {
                if ($scope.cookTopBurnerArray[id].OperationState === 'Pause') {
                    var text = $scope.translation.WEBMOB_device_cooktop_detailed_level_info;
                    text = text.replace(/#1#/, 2);
                    $scope.selectedBurnerDetail = text;
                } else {
                    setSelectedBurnerStatus(id, flexid);
                }
            }
        }
        //debugMessage('current value of ' + id + ' Center text is : ' + value);
        return value;
    }

    function getBurnerTimerStatus(id) {
        var value = '';
        $scope.cookTopBurnerArray[id].BurnerTimeShow = false;
        if (id !== undefined) {
            if ($scope.cookTopBurnerArray[id].OperationState === 'Run' || $scope.cookTopBurnerArray[id].OperationState === 'Pause') {
                if (Number($scope.cookTopBurnerArray[id].DownCountTimerCurrent) > 0) {
                    $scope.cookTopBurnerArray[id].BurnerTimeShow = true;
                    var totalSec = Number($scope.cookTopBurnerArray[id].DownCountTimerCurrent);
                    var h = Math.floor(totalSec / 3600);
                    var min = Math.floor(totalSec % 3600);
                    var m = Math.floor(min / 60);
                    if (h > 0 && m > 0) {
                        value = (h + $scope.translation.WEBMOB_device_range_comm_hr + " " + m + $scope.translation.WEBMOB_common_min);
                    } else if (h > 0 && m <= 0) {
                        value = (h + $scope.translation.WEBMOB_device_range_comm_hr);
                    } else if (m > 0) {
                        value = (m + $scope.translation.WEBMOB_common_min);
                    }
                }
            }
        }
        //debugMessage('current value of ' + id + ' Center text is : ' + value);
        return value;
    }

    function getUpperTextStatus(id) {
        var value = '';
        if (id !== undefined) {
            if ($scope.cookTopBurnerArray[id].OperationState === 'Run' || $scope.cookTopBurnerArray[id].OperationState === 'Pause') {
                value = 'ON';
            }
        }
        //debugMessage('current value of ' + id + ' Upper text is : ' + value);
        return value;
    }

    function getFlexUpperTextStatus(id, flexId) {
        var value = '';
        if (id !== undefined) {
            if ($scope.flexCoilStatus[flexId].FlexOn) {
                value = 'ON';
            }
        }
        //debugMessage('current value of ' + id + ' Upper text is : ' + value);
        return value;
    }

    function getLowerTextStatus(id, flexId) {
        var value = '';
        if (id !== undefined) {
            if (angular.isDefined(flexId) && angular.isDefined($scope.flexCoilStatus[flexId]) && !$scope.flexCoilStatus[flexId].FlexOn) {
                return value = '';
            }
            var upperText = (angular.isDefined(flexId) && angular.isDefined($scope.flexCoilStatus[flexId])) ? $scope.flexCoilStatus[flexId].UpperText : $scope.cookTopBurnerArray[id].UpperText;
            //PowerLevel
            if (($scope.cookTopBurnerArray[id].OperationState === 'Run' || $scope.cookTopBurnerArray[id].OperationState === 'Pause') && upperText !== '') {
                var powerLevel = readChildValue(flexId) ? Number($scope.cookTopBurnerArray[id].PowerLevel) : Number($scope.cookTopBurnerArray[id].PowerLevel);
                if (0 <= powerLevel && powerLevel <= 999) {
                    if (powerLevel !== 0) {
                        $scope.cookTopBurnerArray[id].PowerLevelShow = true;
                        var text = $scope.translation.WEBMOB_device_cooktop_level_info;
                        text = text.replace(/#1#/, Number($scope.cookTopBurnerArray[id].PowerLevel));
                        value = text;
                    } else {
                        value = '';
                        $scope.cookTopBurnerArray[id].PowerLevelShow = false;
                    }
                } else if ($scope.cookTopBurnerArray[id].PowerLevel !== 'Off') {
                    $scope.cookTopBurnerArray[id].PowerLevelShow = true;
                    var status = readChildValue(flexId) ? $scope.cookTopBurnerArray[id].PowerLevel : $scope.cookTopBurnerArray[id].PowerLevel;
                    if (status.toLowerCase().indexOf("melt") !== -1) {
                        value = $scope.translation.WEBMOB_device_cooktop_melt;
                    } else if (status.toLowerCase().indexOf("simmer") !== -1) {
                        value = $scope.translation.WEBMOB_device_cooktop_simmer;
                    } else if (status.toLowerCase().indexOf("boost") !== -1) {
                        value = $scope.translation.WEBMOB_device_cooktop_power_boost;
                    } else {
                        value = $scope.cookTopBurnerArray[id].PowerLevel;
                    }
                }
                $scope.cookTopBurnerArray[id].PowerLevelValue = value;
            }
            //Hotness
            $scope.cookTopBurnerArray[id].Hotness = false;
            if ($scope.cookTopBurnerArray[id].OperationState === 'Ready' || (angular.isDefined(flexId) && angular.isDefined($scope.flexCoilStatus[flexId]) && !$scope.flexCoilStatus[flexId].FlexOn)) {
                var status = readChildValue(flexId) ? $scope.cookTopBurnerArray[id].HotSurface_1 : $scope.cookTopBurnerArray[id].HotSurface;
                if (status === 'SmallHot') {
                    var text = $scope.translation.WEBMOB_device_cooktop_hot;//'Hot';
                    text = text.replace(/#1#/, status);
                    value = text;
                    $scope.cookTopBurnerArray[id].Hotness = true;
                } else if (status === 'Hot') {
                    var text = $scope.translation.WEBMOB_device_cooktop_veryhot;//'Very Hot';
                    text = text.replace(/#1#/, status);
                    value = text;
                    $scope.cookTopBurnerArray[id].Hotness = true;
                } else {
                    ;//NULL
                }
            }
            //Burner Time
            var timervalue = getBurnerTimerStatus(id);
            if (timervalue !== '') {
                $scope.cookTopBurnerArray[id].BurnerTime = timervalue;
                if (angular.isDefined(flexId)) {
                    value = value === '' && $scope.flexCoilStatus[flexId].UpperText === 'ON' ? timervalue : value;
                } else {
                    value = value === '' && $scope.cookTopBurnerArray[id].UpperText === 'ON' ? timervalue : value;
                }
            }
        }
        //debugMessage('current value of ' + id + ' Lower text is : ' + value);
        return value;
    }

    function setSelectedBurnerStatus(id, flexId) {
        var detailText = "";
        $scope.SelectedRecipe = '';
        detailText = (angular.isDefined(flexId) && angular.isDefined($scope.flexCoilStatus[flexId]) && $scope.flexCoilSelectedValue !== -1) ?
                $scope.flexCoilStatus[$scope.flexCoilSelectedValue].LowerText : $scope.cookTopBurnerArray[id].LowerText;
        if (detailText !== '' && $scope.cookTopBurnerArray[id].ImageSelected) {
            $scope.showBurnerTimer = $scope.cookTopBurnerArray[id].BurnerTimeShow;
            $scope.showFlexPowerLevel = $scope.cookTopBurnerArray[id].PowerLevel;
            $scope.showCenterText = false;
        } else {
            detailText = (angular.isDefined(flexId) && angular.isDefined($scope.flexCoilStatus[flexId]) && $scope.flexCoilSelectedValue !== -1) ?
                    $scope.flexCoilStatus[$scope.flexCoilSelectedValue].CenterText : detailText = $scope.cookTopBurnerArray[id].CenterText;

            var text = $scope.translation.WEBMOB_device_cooktop_burner_state;
            text = text.replace(/#1#/, detailText.toLowerCase());
            $scope.selectedBurnerDetail = text;
            $scope.showBurnerTimer = false;
            $scope.showFlexPowerLevel = false;
            $scope.showCenterText = true;
        }
        if ($scope.cookTopBurnerArray[id].Hotness) {
            var text = $scope.translation.WEBMOB_device_cooktop_burner_state;
            text = text.replace(/#1#/, 'off');
            $scope.selectedBurnerDetail = text + '<br>' + $scope.translation["WEBMOB_device_cooktop_hot_alarm"];
            $scope.showBurnerTimer = false;
            $scope.showFlexPowerLevel = false;
            $scope.showCenterText = true;
        }
        if (angular.isDefined($scope.cookTopBurnerArray[id].GuidedCooking) && $scope.cookTopBurnerArray[id].GuidedCooking > 0) {
            $scope.SelectedRecipe = $scope.CooktopRecipes[($scope.cookTopBurnerArray[id].GuidedCooking) - 1];
        }
    }

    function showPowerLevelDetail() {
        if ($scope.flexCoilSelectedValue > -1) {
            return ($scope.cookTopBurnerArray[$scope.burnerSelectedValue].PowerLevelShow && $scope.flexCoilStatus[$scope.flexCoilSelectedValue].CenterText === '');
        }
        return ($scope.cookTopBurnerArray[$scope.burnerSelectedValue].PowerLevelShow && $scope.cookTopBurnerArray[$scope.burnerSelectedValue].CenterText === '');
    }

    function showBurnerTimeDetail() {
        if ($scope.flexCoilSelectedValue > -1) {
            return $scope.cookTopBurnerArray[$scope.burnerSelectedValue].BurnerTimeShow && $scope.flexCoilStatus[$scope.flexCoilSelectedValue].CenterText === '';
        }
        return $scope.cookTopBurnerArray[$scope.burnerSelectedValue].BurnerTimeShow && $scope.cookTopBurnerArray[$scope.burnerSelectedValue].CenterText === '';
    }
    
    function setBurnerTimer() {
        if ($scope.flexCoilSelectedValue > -1) {
            return $scope.DeviceModelName !== 'NV9500M-/KO0' && !$scope.cookTopBurnerArray[$scope.burnerSelectedValue].BurnerTimeShow && $scope.flexCoilStatus[$scope.flexCoilSelectedValue].CenterText !== 'OFF';
        }
        return $scope.DeviceModelName !== 'NV9500M-/KO0' && !$scope.cookTopBurnerArray[$scope.burnerSelectedValue].BurnerTimeShow && $scope.cookTopBurnerArray[$scope.burnerSelectedValue].CenterText === '';
    }

    function selectBurner(burnerId) {
        debugMessage('selected Burner ' + burnerId);
        bridgeSelected = 'off';
        $scope.flexCoilSelectedValue = -1;
        $scope.burnerSelectedValue = burnerId;
        $scope.cookTopBurnerArray[0].ImageSelected = false;
        $scope.cookTopBurnerArray[1].ImageSelected = false;
        $scope.cookTopBurnerArray[2].ImageSelected = false;
        $scope.cookTopBurnerArray[3].ImageSelected = false;
        $scope.cookTopBurnerArray[4].ImageSelected = false;
        $scope.cookTopBurnerArray[5].ImageSelected = false;
        if (document.getElementById('burnerDetail') !== null) {
            document.getElementById("burnerDetail").style.visibility = "hidden";
        }
        if (burnerId === -2) {
            if ($scope.cookTopInfo.Mode.options[0].SyncFlex === 'On') {
                $scope.cookTopBurnerArray[0].ImageSelected = true;
                $scope.cookTopBurnerArray[1].ImageSelected = true;
            }
        } else if (burnerId === -1) {
            ;//NULL
        } else {
            $scope.cookTopBurnerArray[burnerId].ImageSelected = true;
            if (document.getElementById('burnerDetail') !== null) {
                //document.getElementById("burnerDetail").style.visibility = "visible";
            }
            if ($scope.cookTopBurnerArray[burnerId].PanSize === 'Single') {
                $scope.cookTopBurnerArray[burnerId].subBurnerId = '_01';
            } else if ($scope.cookTopBurnerArray[burnerId].PanSize === 'Dual') {
                $scope.cookTopBurnerArray[burnerId].subBurnerId = '_02';
            } else if ($scope.cookTopBurnerArray[burnerId].PanSize === 'Triple') {
                $scope.cookTopBurnerArray[burnerId].subBurnerId = '_03';
            } else {
                $scope.cookTopBurnerArray[burnerId].subBurnerId = '';
            }

            setSelectedBurnerStatus($scope.burnerSelectedValue);
            showBurnerInfoPopups();
        }

        updateBrige();
        updateCookTopBurnerValues();
    }

    function updateBrige() {
        if ($scope.showBrige) {
            if ($scope.cookTopInfo.Mode.options[0].SyncFlex === 'On') {
                if ($scope.cookTopBurnerArray[0].ImageSelected || $scope.cookTopBurnerArray[1].ImageSelected) {
                    bridgeSelected = 'select';
                    $scope.cookTopBurnerArray[0].ImageSelected = true;
                    $scope.cookTopBurnerArray[1].ImageSelected = true;
                    var text = $scope.translation.WEBMOB_device_cooktop_detailed_level_info;
                    var splitLevelInfo = $scope.cookTopBurnerArray[0].LowerText.split(' ');
                    var val = (splitLevelInfo instanceof Array && angular.isDefined(splitLevelInfo[1])) ? splitLevelInfo[1] : $scope.cookTopBurnerArray[0].LowerText;
                    text = text.replace(/#1#/, val);
                    $scope.selectedBurnerDetail = text;
                } else {
                    if (Number($scope.cookTopBurnerArray[0].PowerLevel) > 0) {
                        bridgeSelected = 'on';
                    } else {
                        bridgeSelected = 'off';
                    }
                    $scope.cookTopBurnerArray[0].ImageSelected = false;
                    $scope.cookTopBurnerArray[1].ImageSelected = false;
                }
            } else {
                bridgeSelected = 'off';
                if ($scope.cookTopBurnerArray[0].ImageSelected && $scope.cookTopBurnerArray[1].ImageSelected) {
                    $scope.cookTopBurnerArray[0].ImageSelected = false;
                    $scope.cookTopBurnerArray[1].ImageSelected = false;
                }
            }
            $scope.cookTopBurnerBridge = $scope.cookTopBaseImage + '_burner_sync_' + bridgeSelected;
        }
    }

    function updateTimerValue(value) {
        debugMessage('updateTimerValue according to ' + value);
        value = Number(value);
        if (value > 779) {
            value = 779;
        }
        if (!$scope.supportHrTimer) {
            document.getElementById('kitchenTimer').value = value;
            if (value < 10) {
                document.getElementById('kitchenTimer').value = '0' + value;
            }
        } else {
            var hr = Math.floor(value / 60);
            var min = Math.floor(value % 60);
            document.getElementById('kchnTimrHr').value = hr;
            document.getElementById('kchnTimrMn').value = min;
            if (hr < 10) {
                document.getElementById('kchnTimrHr').value = '0' + hr;
            }
            if (min < 10) {
                document.getElementById('kchnTimrMn').value = '0' + min;
            }
        }
        if (value >= 1) {
            $scope.timerText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        } else {
            $scope.timerText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1;
        }
        if ($scope.KitchenTimerState === 'Run' && (value === $scope.cookTopInfo.Mode.options[0].MainTimerCurrent || value < 1)) {
            $scope.startStopState = $scope.translation.WEBMOB_common_cooktop_pause;
            $scope.timerStopText = (value < 1) ? $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1 : $scope.translation.WEBMOB_device_hood_set_time_reset_for_stop;
        } else if ($scope.KitchenTimerState === 'Pause') {
            $scope.startStopState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;//'PAUSE'
            $scope.timerStopText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start_for_resume;
        } else {
            $scope.startStopState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
            $scope.timerStopText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        }
    }

    function updateBurnerTimerValue(value) {
        debugMessage('updateBurnerTimerValue according to ' + value);
        value = Number(value);
        if (value > 779) {
            value = 779;
        }
        var hr = Math.floor(value / 60);
        var min = Math.floor(value % 60);
        document.getElementById('brnrTimrHr').value = hr;
        document.getElementById('brnrTimrMn').value = min;
        if (hr < 10) {
            document.getElementById('brnrTimrHr').value = '0' + hr;
        }
        if (min < 10) {
            document.getElementById('brnrTimrMn').value = '0' + min;
        }
        if (value >= 1) {
            $scope.timerText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        } else {
            $scope.timerText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1;
        }
        if ($scope.BurnerTimerState === 'Run' && (value === Math.floor($scope.cookTopBurnerArray[$scope.selectedBurnerTimer].DownCountTimerCurrent / 60))) {
            $scope.startStopBurnerState = $scope.translation.WEBMOB_common_cooktop_pause;
            $scope.timerStopText = (value < 1) ? $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1 : $scope.translation.WEBMOB_device_hood_set_time_guide4;
        } else if ($scope.BurnerTimerState === 'Pause') {
            $scope.startStopBurnerState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
            $scope.timerStopText = $scope.translation.WEBMOB_device_hood_set_time_guide4;
        } else {
            $scope.startStopBurnerState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
            $scope.timerStopText = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        }
    }

    function updateHoodTimerValue(value) {
        debugMessage('updateHoodTimerValue according to ' + value);
        value = Number(value);
        if (!$scope.supportHrTimer) {
            document.getElementById('hoodTimer').value = value;
            if (value < 10) {
                document.getElementById('hoodTimer').value = '0' + value;
            }
        } else {
            var hr = Math.floor(value / 60);
            var min = Math.floor(value % 60);
            document.getElementById('hoodTimrHr').value = hr;
            document.getElementById('hoodTimrMn').value = min;
            if (hr < 10) {
                document.getElementById('hoodTimrHr').value = '0' + hr;
            }
            if (min < 10) {
                document.getElementById('hoodTimrMn').value = '0' + min;
            }
        }
        if (value >= 1) {
            $scope.timerTextHood = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        } else {
            $scope.timerTextHood = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1;
        }

        if ($scope.HoodTimerState === 'Run' && (value === $scope.HoodInfo.Mode.options[0].ShutOffTimerCurrent || value < 1)) {
            $scope.startStopHoodState = $scope.translation.WEBMOB_device_hood_stop_button;
            /*
             * In run state if user swipes the round progress bar to value 0, change the stop message 
             */
            $scope.timerStopTextHood = (value < 1) ? $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step1 : $scope.translation.WEBMOB_device_hood_set_time_guide4;
        } else {
            $scope.startStopHoodState = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_start;
            $scope.timerStopTextHood = $scope.translation.WEBMOB_device_cooktop_kitchen_timer_step2;
        }
    }

    function inputKeyDown(e) {
        if (e === undefined) {
            return;
        }
        var inputElement = document.activeElement;
        $timeout(function () {
            var sanitized = $(inputElement).val().replace(/[^0-9]/g, '');
            $(inputElement).val("");
            $(inputElement).val(sanitized);
        }, 0);
        var id = e.currentTarget.id;
        var ID = id.substring(0, 8);
        document.getElementById(id).onkeyup = function (e) {
            if (this.value === '' || !angular.isDefined(Number(this.value))) {
                e.preventDefault();
                var val = 0;
                if ($scope.supportHrTimer) {
                    if (id === (ID + 'Hr')) {
                        val = Number(document.getElementById((ID + 'Mn')).value);
                    } else if (id === (ID + 'Mn')) {
                        val = Number(document.getElementById((ID + 'Hr')).value) * 60;
                    }
                }
                roundShape.roundSlider({value: val, sliderType: "min-range", tab: roundShape === hoodTimerDrag ? 2 : 1});
                document.getElementById(id).value = '';
                return;
            }
            checkForKey(e, this.value, id, ID);
        };
    }

    function checkForKey(e, str, id, ID) {
        var key = e.keyCode || e.which;
        if (key === 0 || key === 229) {
            key = str.charCodeAt(str.length - 1);
        }
        if ((key >= 96 && key <= 105 || key >= 48 && key <= 57) || key !== 8 || key !== 46) {
            var textValue;
            if (!$scope.supportHrTimer) {
                textValue = Number(document.getElementById(id).value);
                roundShape.roundSlider({value: Number(textValue), sliderType: "min-range", tab: roundShape === hoodTimerDrag ? 2 : 1});
                document.getElementById(id).value = textValue;
            } else {
                var hr = Number(document.getElementById(ID + 'Hr').value);
                var min = Number(document.getElementById(ID + 'Mn').value);
                if (min > 59) {
                    min = Math.floor(min / 10);
                }
                if (hr > 12) {
                    hr = Math.floor(hr / 10);
                }
                textValue = (hr * 60) + min;
                roundShape.roundSlider({value: Number(textValue), sliderType: "min-range", tab: roundShape === hoodTimerDrag ? 2 : 1});
                var hr = Math.floor(textValue / 60);
                var min = Math.floor(textValue % 60);
                document.getElementById(ID + 'Hr').value = hr;
                document.getElementById(ID + 'Mn').value = min;
                if (hr < 10 && id !== (ID + 'Hr')) {
                    document.getElementById(ID + 'Hr').value = '0' + hr;
                }
                if (min < 10 && id !== (ID + 'Mn')) {
                    document.getElementById(ID + 'Mn').value = '0' + min;
                }
            }
        }

        if (key === 9 && (id.indexOf("Tim") !== -1)) {
            showDummyInbox();
        }

        if (!(key >= 96 && key <= 105 || key >= 48 && key <= 57) && key !== 9 && key !== 8 && key !== 46) {
            e.preventDefault();
            return;
        }
    }

    function showDummyInbox() {
        debugMessage("showDummyInbox");
        if ((window.navigator.platform !== 'iPhone' || window.navigator.platform !== 'iPad')) {
            $scope.isTempFocusOn = true;
            document.activeElement.blur();
        }
    }

    function hideDummyInbox() {
        debugMessage("hideDummyInbox");
        $scope.isTempFocusOn = false;
    }

    function disableDummyInbox() {
        debugMessage("disableDummyInbox");
        if (document.getElementById("dummyInputBox") !== null) {
            document.getElementById("dummyInputBox").disabled = true;
        }
    }

    function showToast(txt) {
        debugMessage("showToast with txt " + txt);
        $timeout(function () {
            toaster.success({title: "", body: txt, bodyOutputType: 'trustedHtml'});
        }, 500);
    }

    function hideInputBoxFocus() {
        blurInputBox('dummyInputBox');
        blurInputBox('kchnTimrHr');
        blurInputBox('kchnTimrMn');
        blurInputBox('kitchenTimer');
        blurInputBox('brnrTimrHr');
        blurInputBox('brnrTimrMn');
        blurInputBox('hoodTimer');
    }

    function blurInputBox(id) {
        debugMessage("blurInputBox");
        if (document.getElementById(id) !== null && document.getElementById(id) !== undefined) {
            document.getElementById(id).blur();
            if (isTextInput(document.activeElement)) {
                document.activeElement.blur();
            }
        }
    }

    function showcustDialog(myAlertState, msgHeader, popuptext, txtButton1, txtButton2) {
        debugMessage("showcustDialog " + myAlertState + " " + msgHeader + " " + popuptext + " " + txtButton1 + " " + txtButton2);
        $scope.alertState = myAlertState;
        $scope.custPopupTitle = true;
        $scope.custPopupOKBtton = true;
        $scope.showFullScreenPopup = true;
        $scope.custPopupCancelButton = true;
        $scope.custPopupTitleText = msgHeader;
        $scope.custPopupMessageText = popuptext;
        $scope.custPopupCancelOkText = txtButton1;
        $scope.custPopupCancelButtonText = txtButton2;

        $scope.showMenuOptionPopup = false;

        $timeout(function () {
            document.getElementById("fullScreenPopupId").style.zIndex = 999;
            document.getElementById("custPopupDivId").style.zIndex = 999;
        }, 0);
        /*$timeout(function () {
         document.getElementById("bodyTag").style.pointerEvents = 'none';
         }, 200);*/
        $timeout(function () {
            var cHeight = 0, cWidth = 0, popupHeight = 0, base = 0, popupTop = 12;
            cHeight = window.screen.availHeight;
            cWidth = window.screen.availWidth;
            if (cHeight === 0 || cHeight === undefined) {
                cHeight = document.body.clientHeight;
            }
            if (cWidth === 0 || cWidth === undefined) {
                cWidth = document.body.clientWidth;
            }
            base = 2 * ((80 * cWidth) / 1440);
            popupHeight = document.getElementById("custPopupDivId").clientHeight;
            if (popupHeight !== 0 && popupHeight !== undefined && popupHeight !== '' && base > 0) {
                popupTop = (cHeight - popupHeight) / base;
            }
            document.getElementById("custPopupDivId").style.top = popupTop + 'rem';
        }, 10);


        if (msgHeader === undefined || msgHeader === '') {
            $scope.custPopupTitle = false;
        }
        if (txtButton1 === undefined || txtButton1 === '') {
            $scope.custPopupOKBtton = false;
        }
        if (txtButton2 === undefined || txtButton2 === '') {
            $scope.custPopupCancelButton = false;
        }

    }

    function onAlertButton1Click() {
        debugMessage("onAlertButton1Click " + $scope.alertState);
        $scope.showFullScreenPopup = false;
        $timeout(function () {
            switch ($scope.alertState) {
                case COOKTOP_ALERT_STATE.ALERT_NONE:
                    break;
                case COOKTOP_ALERT_STATE.ALERT_CONNECTION_ERROR:
                    closeApp();
                    break;
                case COOKTOP_ALERT_STATE.ALERT_TIMER_FINISH:
                case COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER:
                    debugMessage("Kitchen Timer pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_HOOD_TIMER_FINISH:
                    debugMessage("Hood Timer pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_DEVELOPER_INFO:
                    debugMessage("Developer info pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_CHILD_LOCK:
                    debugMessage("Child lock pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_SERVICE_CALL:
                    callServieCenter();
                    break;
                default:
                    break;
            }
        }, 200);

    }

    function onAlertButton2Click() {
        debugMessage("onAlertButton2Click " + $scope.alertState);
        $scope.showFullScreenPopup = false;
        $timeout(function () {
            switch ($scope.alertState) {
                case COOKTOP_ALERT_STATE.ALERT_START_COOKING:
                    break;
                case COOKTOP_ALERT_STATE.ALERT_CONNECTION_ERROR:
                    debugMessage("cancel connection pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_TIMER_FINISH:
                case COOKTOP_ALERT_STATE.ALERT_BURNER_TIMER:
                    debugMessage("ok Kitchen Timer pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_HOOD_TIMER_FINISH:
                    debugMessage("Hood Timer pop up");
                    $scope.cTopTabSelected = false;
                    showHoodScreen();
                    validateCurrentScreen('BurnerHomePage');
                    break;
                case COOKTOP_ALERT_STATE.ALERT_DEVELOPER_INFO:
                    debugMessage("ok Developer info pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_CHILD_LOCK:
                    debugMessage("ok Child lock pop up");
                    break;
                case COOKTOP_ALERT_STATE.ALERT_SERVICE_CALL:
                    debugMessage("cancel service center call");
                    break;
                default:
                    break;
            }
            debugMessage("onAlertButton2Click");
        }, 200);
    }

    function smartcareerrorcheck() {
        if (!$scope.isStatic) {
            $scope.checkResponse.push(COOKTOP_COMMANDS.smartCareDiagnosis);
            debugMessage("Send command for smartCareDiagnosis " + getDiagnosisCommand());
            SHPService.sendSHPCommand(CONSTANTS.PUT, getDiagnosisCommand(), "/" + $scope.peerId + "/devices/0/diagnosis");
        } else {
            $scope.cookTopInfo.Alarms[0].code = "CT_E_F0";
            showCurrentScreen();
        }
    }

    function getDiagnosisCommand() {
        return '{"Diagnosis": {"diagnosisStart": "Run"}}';
    }

    function getErrorCode(errorEnum) {
        switch (errorEnum) {
            case 'CT_E_d0':
                return "C-d0";
            case 'CT_E_F0':
                return "C-F0";
            case 'CT_E_F1':
                return "C-F1";
            case 'CT_E_F2':
                return "C-F2";
            case 'CT_E_30':
                return "C-30";
            case 'CT_E_31':
                return "C-31";
            case 'CT_E_A2':
                return "C-A2";
            case 'CT_E_C0':
                return "C-C0";
            case 'CT_E_C1':
                return "C-C1";
            case 'CT_E_C2':
                return "C-C2";
            case 'undefined':
            default:
                return "";
        }
    }

    function getAlarmStatusCooktop() {
        //$scope.cookTopInfo.Alarms[0].code = "CT_E_F0";
        if ($scope.cookTopInfo.Alarms[0] !== undefined && $scope.cookTopInfo.Alarms[0] !== null && $scope.cookTopInfo.Alarms[0].code !== '-1') {
            debugMessage('Check for alarm status 0 :' + $scope.cookTopInfo.Alarms[0].code);

            if ($scope.cookTopInfo.Alarms[0].code === 'CT_E') {
                $scope.cookTopInfo.Alarms[0].code = '-1';
                errorRemoved = true;
                return false;
            }

            if (!errorRemoved) {
                debugMessage('Check error status');
                return;
            }

            if ($scope.cookTopInfo.Alarms[0].code.indexOf("CT_E") !== -1) {
                $scope.errorCode = getErrorCode($scope.cookTopInfo.Alarms[0].code);
                if ($scope.errorCode !== '') {
                    errorRemoved = false;
                    validateCurrentScreen('ErrorPage');
                    return true;
                } else {
                    return false;
                }
            }
        }
        return false;
    }

    function doOnServiceCallPopup() {
        showcustDialog(COOKTOP_ALERT_STATE.ALERT_SERVICE_CALL, $scope.translation.WEBMOB_common_service_call, ($scope.translation.WEBMOB_common_connect_service_call) + "<br>" + $scope.serviceCenterNumber, $scope.translation.WEBMOB_common_cancel_capital, $scope.translation.WEBMOB_common_ok);
    }

    function callServieCenter() {
        debugMessage("call service center");
        nativeInterface.runOnNative("callDial", '{"selectedCountry" : "' + $scope.selectedCountry + '"}');
    }

    function aboutCommand(cmdstring) {
        return '{"service" : "' + cmdstring + '","selectedCountry" : "' + $scope.selectedCountry + '"}';
    }

    function onFlexCoilClicked(val) {
        debugMessage('onFlexCoilClicked :' + val);
        $scope.flexCoilSelectedValue = val;
        $scope.cookTopBurnerArray[0].ImageSelected = ($scope.flexCoilSelectedValue === 0 || $scope.flexCoilSelectedValue === 1) ? true : false;
        $scope.cookTopBurnerArray[1].ImageSelected = ($scope.flexCoilSelectedValue === 2 || $scope.flexCoilSelectedValue === 3) ? true : false;
        $scope.cookTopBurnerArray[2].ImageSelected = false;
        $scope.cookTopBurnerArray[3].ImageSelected = false;
        $scope.cookTopBurnerArray[4].ImageSelected = ($scope.flexCoilSelectedValue === 4 || $scope.flexCoilSelectedValue === 5) ? true : false;
        $scope.cookTopBurnerArray[5].ImageSelected = ($scope.flexCoilSelectedValue === 6 || $scope.flexCoilSelectedValue === 7) ? true : false;

        if (document.getElementById('burnerDetail') !== null) {
            //document.getElementById("burnerDetail").style.visibility = "visible";
        }
        var parentBurner = 0;
        if ($scope.flexCoilSelectedValue === 0 || $scope.flexCoilSelectedValue === 1) {
            parentBurner = 0;
        } else if ($scope.flexCoilSelectedValue === 2 || $scope.flexCoilSelectedValue === 3) {
            parentBurner = 1;
        } else if ($scope.flexCoilSelectedValue === 4 || $scope.flexCoilSelectedValue === 5) {
            parentBurner = 4;
        } else if ($scope.flexCoilSelectedValue === 6 || $scope.flexCoilSelectedValue === 7) {
            parentBurner = 5;
        }
        $scope.burnerSelectedValue = parentBurner;
        setSelectedBurnerStatus(parentBurner, val);
        showBurnerInfoPopups();
    }

    function checkPauseState() {
        var isPause = false;
        if ($scope.cookTopBurnerArray[0].OperationState === 'Pause'
                || $scope.cookTopBurnerArray[1].OperationState === 'Pause'
                || $scope.cookTopBurnerArray[2].OperationState === 'Pause'
                || $scope.cookTopBurnerArray[3].OperationState === 'Pause'
                || $scope.cookTopBurnerArray[4].OperationState === 'Pause'
                || $scope.cookTopBurnerArray[5].OperationState === 'Pause') {
            isPause = true;
        }
        return isPause;
    }

    function setLocalStorageData(item, value) {
        debugMessage('setLocalStorageData');
        if (value === true && $scope.isStatic) {
            return;
        }
        if (typeof (Storage) !== "undefined") {
            localStorage.setItem(item, value);
        } else {
            ;//NULL
        }
    }
    
    window.onresize = updateScrollableHeight;
    $scope.$watch(function () {
        return angular.isDefined(scroll_middle_area[0]) && scroll_middle_area[0].offsetTop;
    }, function () {
        updateScrollableHeight();
    });

    /**
     * Update the height of the scrolalbe area.
     */
    function updateScrollableHeight() {
        $timeout(function () {
            var scrollableElement = scroll_middle_area[0];
            var area4 = document.getElementsByClassName('ap-search-list-property');
            if (scrollableElement) {
                var screenSize = document.body.clientHeight,
                        scrollableOffsetTop = scrollableElement.getBoundingClientRect().top;
                //set new height to scrollable area
                scrollableElement.style.height = (screenSize - scrollableOffsetTop) + "px";
            }
            if (area4.length > 0) {
                var scrollableElement = area4[0],
                        screenSize = document.body.clientHeight,
                        scrollableOffsetTop = scrollableElement.getBoundingClientRect().top;
                scrollableElement.style.height = (screenSize - scrollableOffsetTop) + "px";
            }
        }, 100);
    }

    if ($scope.isStatic) {
        parseStaticData();
    }
}

app.directive('stPressEffect', function (UtilityService) {
    return {
        restrict: 'A',
        link: function ($scope, $elm, $attrs) {
            var mouseEvts = {
                'touchstart': touchStartFun,
                'touchend': touchEndFun,
                'touchleave': touchEndFun,
                'touchcancel': touchEndFun,
                'touchmove': touchMoveFun
            },
                    evnt;
            for (evnt in mouseEvts) {
                if (mouseEvts.hasOwnProperty(evnt) &&
                        UtilityService.isEventSupported(evnt)) {
                    $elm.bind(evnt, mouseEvts[evnt]);
                }
            }
            function touchStartFun() {
                $scope.$parent[$attrs.stPressEffect] = true;
                $scope.$apply();
            }
            function touchMoveFun(evt) {
                if (evt.touches !== undefined && evt.touches.length !== undefined && evt.touches[evt.touches.length - 1] !== undefined && evt.currentTarget !== undefined && evt.currentTarget.parentElement !== undefined) {
                    if (evt.touches[evt.touches.length - 1].clientY <= evt.currentTarget.parentElement.clientHeight || evt.touches[evt.touches.length - 1].clientX <= evt.currentTarget.parentElement.clientWidth) {
                        touchStartFun();
                    }
                } else {
                    touchEndFun();
                }
            }
            function touchEndFun() {
                $scope.$parent[$attrs.stPressEffect] = false;
                $scope.$apply();
            }
        }
    };
});

function updateKitchenTimerValue(value, tab) {
    var scope = angular.element($("#bodyTag")).scope();
    if (tab === 2) {
        scope.hoodTimer = Number(value);
        scope.updateHoodTimerValue(scope.hoodTimer);
    } else if (tab === 3) {
        scope.burnerTimer = Number(value);
        scope.updateBurnerTimerValue(scope.burnerTimer);
    } else {
        scope.kitchenTimer = Number(value);
        scope.updateTimerValue(scope.kitchenTimer);
    }
    if (scope.$root.$$phase !== '$apply' && scope.$root.$$phase !== '$digest') {
        scope.$apply();
    }
}
